@@ -18,7 +18,6 @@ package org.gradle.api.specs;
 /**
  * A {@link org.gradle.api.specs.Spec} implementation which negates another {@code Spec}.
  * 
- * @author Hans Dockter
  * @param <T> The target type for this Spec
  */
 public class NotSpec<T> implements Spec<T> {
@@ -28,6 +27,10 @@ public class NotSpec<T> implements Spec<T> {
         this.sourceSpec = sourceSpec;
     }
 
+    Spec<? super T> getSourceSpec() {
+        return sourceSpec;
+    }
+
     public boolean isSatisfiedBy(T element) {
         return !sourceSpec.isSatisfiedBy(element);
     }
