@@ -15,18 +15,24 @@
  */
 package org.gradle.api.internal.changedetection.state;
 
+import com.google.common.base.Function;
+import com.google.common.base.Predicate;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.ImmutableSortedMap;
+import com.google.common.collect.Iterables;
 import com.google.common.collect.Sets;
 import com.google.common.hash.HashCode;
 import org.gradle.api.internal.TaskInternal;
 import org.gradle.api.internal.cache.StringInterner;
 import org.gradle.api.internal.project.ProjectInternal;
+import org.gradle.api.internal.tasks.CacheableTaskOutputFilePropertySpec;
+import org.gradle.api.internal.tasks.TaskOutputFilePropertySpec;
 import org.gradle.cache.PersistentIndexedCache;
 import org.gradle.cache.internal.AsyncCacheAccessContext;
 import org.gradle.internal.Cast;
+import org.gradle.internal.serialize.AbstractSerializer;
 import org.gradle.internal.serialize.Decoder;
 import org.gradle.internal.serialize.Encoder;
 import org.gradle.internal.serialize.Serializer;
@@ -38,7 +44,6 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Deque;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -55,13 +60,14 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
         this.snapshotRepository = snapshotRepository;
         this.stringInterner = stringInterner;
         this.serializer = new TaskExecutionListSerializer(stringInterner);
-        taskHistoryCache = cacheAccess.createCache("taskArtifacts", String.class, serializer);
+        taskHistoryCache = cacheAccess.createCache("taskHistory", String.class, serializer, 2000, false);
     }
 
     public History getHistory(final TaskInternal task) {
         final TaskExecutionList previousExecutions = loadPreviousExecutions(task);
         final LazyTaskExecution currentExecution = new LazyTaskExecution();
         currentExecution.snapshotRepository = snapshotRepository;
+        currentExecution.setOutputPropertyNamesForCacheKey(getOutputPropertyNamesForCacheKey(task));
         currentExecution.setDeclaredOutputFilePaths(getDeclaredOutputFilePaths(task));
         final LazyTaskExecution previousExecution = findBestMatchingPreviousExecution(currentExecution, previousExecutions.executions);
         if (previousExecution != null) {
@@ -138,12 +144,34 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
         }
     }
 
+    private Iterable<String> getOutputPropertyNamesForCacheKey(TaskInternal task) {
+        // Find all output properties that go into the cache key
+        Iterable<TaskOutputFilePropertySpec> outputPropertiesForCacheKey =
+            Iterables.filter(task.getOutputs().getFileProperties(), new Predicate<TaskOutputFilePropertySpec>() {
+                @Override
+                public boolean apply(TaskOutputFilePropertySpec propertySpec) {
+                    if (propertySpec instanceof CacheableTaskOutputFilePropertySpec) {
+                        CacheableTaskOutputFilePropertySpec cacheablePropertySpec = (CacheableTaskOutputFilePropertySpec)propertySpec;
+                        return cacheablePropertySpec.getOutputFile() != null;
+                    }
+                    return false;
+                }
+        });
+        // Extract the output property names
+        return Iterables.transform(outputPropertiesForCacheKey, new Function<TaskOutputFilePropertySpec, String>() {
+            @Override
+            public String apply(TaskOutputFilePropertySpec propertySpec) {
+                return propertySpec.getPropertyName();
+            }
+        });
+    }
+
     private ImmutableSet<String> getDeclaredOutputFilePaths(TaskInternal task) {
-        Set<String> declaredOutputFilePaths = new HashSet<String>();
+        ImmutableSet.Builder<String> declaredOutputFilePaths = ImmutableSet.builder();
         for (File file : task.getOutputs().getFiles()) {
             declaredOutputFilePaths.add(stringInterner.intern(file.getAbsolutePath()));
         }
-        return ImmutableSet.copyOf(declaredOutputFilePaths);
+        return declaredOutputFilePaths.build();
     }
 
     private LazyTaskExecution findBestMatchingPreviousExecution(TaskExecution currentExecution, Collection<LazyTaskExecution> previousExecutions) {
@@ -170,7 +198,7 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
         return bestMatch;
     }
 
-    private static class TaskExecutionListSerializer implements Serializer<ImmutableList<TaskExecutionSnapshot>> {
+    private static class TaskExecutionListSerializer extends AbstractSerializer<ImmutableList<TaskExecutionSnapshot>> {
         private static final String CONTEXT_KEY_FOR_CLASSLOADER = AsyncCacheAccessContext.createKey(TaskExecutionListSerializer.class, "classLoader");
         private final StringInterner stringInterner;
 
@@ -249,6 +277,7 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
             setTaskActionsClassLoaderHash(taskExecutionSnapshot.getTaskActionsClassLoaderHash());
             // Take copy of input properties map
             setInputProperties(new HashMap<String, Object>(taskExecutionSnapshot.getInputProperties()));
+            setOutputPropertyNamesForCacheKey(taskExecutionSnapshot.getCacheableOutputProperties());
             setDeclaredOutputFilePaths(taskExecutionSnapshot.getDeclaredOutputFilePaths());
             inputFilesSnapshotIds = taskExecutionSnapshot.getInputFilesSnapshotIds();
             outputFilesSnapshotIds = taskExecutionSnapshot.getOutputFilesSnapshotIds();
@@ -312,6 +341,7 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
         public TaskExecutionSnapshot snapshot() {
             return new TaskExecutionSnapshot(
                 getTaskClass(),
+                getOutputPropertyNamesForCacheKey(),
                 getDeclaredOutputFilePaths(),
                 getTaskClassLoaderHash(),
                 getTaskActionsClassLoaderHash(),
@@ -343,12 +373,20 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
                 if (decoder.readBoolean()) {
                     taskActionsClassLoaderHash = HashCode.fromBytes(decoder.readBinary());
                 }
-                int outputFiles = decoder.readSmallInt();
-                Set<String> files = new HashSet<String>();
-                for (int j = 0; j < outputFiles; j++) {
-                    files.add(stringInterner.intern(decoder.readString()));
+
+                int cacheableOutputPropertiesCount = decoder.readSmallInt();
+                ImmutableSet.Builder<String> cacheableOutputPropertiesBuilder = ImmutableSet.builder();
+                for (int j = 0; j < cacheableOutputPropertiesCount; j++) {
+                    cacheableOutputPropertiesBuilder.add(decoder.readString());
                 }
-                ImmutableSet<String> declaredOutputFilePaths = ImmutableSet.copyOf(files);
+                ImmutableSet<String> cacheableOutputProperties = cacheableOutputPropertiesBuilder.build();
+
+                int outputFilesCount = decoder.readSmallInt();
+                ImmutableSet.Builder<String> declaredOutputFilePathsBuilder = ImmutableSet.builder();
+                for (int j = 0; j < outputFilesCount; j++) {
+                    declaredOutputFilePathsBuilder.add(stringInterner.intern(decoder.readString()));
+                }
+                ImmutableSet<String> declaredOutputFilePaths = declaredOutputFilePathsBuilder.build();
 
                 boolean hasInputProperties = decoder.readBoolean();
                 Map<String, Object> inputProperties;
@@ -359,6 +397,7 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
                 }
                 return new TaskExecutionSnapshot(
                     taskClass,
+                    cacheableOutputProperties,
                     declaredOutputFilePaths,
                     taskClassLoaderHash,
                     taskActionsClassLoaderHash,
@@ -388,6 +427,10 @@ public class CacheBackedTaskHistoryRepository implements TaskHistoryRepository {
                     encoder.writeBoolean(true);
                     encoder.writeBinary(actionsClassLoaderHash.asBytes());
                 }
+                encoder.writeSmallInt(execution.getCacheableOutputProperties().size());
+                for (String outputFile : execution.getCacheableOutputProperties()) {
+                    encoder.writeString(outputFile);
+                }
                 encoder.writeSmallInt(execution.getDeclaredOutputFilePaths().size());
                 for (String outputFile : execution.getDeclaredOutputFilePaths()) {
                     encoder.writeString(outputFile);
