@@ -16,6 +16,7 @@
 
 package org.gradle.api.internal.tasks;
 
+import org.gradle.api.internal.changedetection.state.FileCollectionSnapshotter;
 import org.gradle.api.internal.changedetection.state.SnapshotNormalizationStrategy;
 import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.TaskFilePropertyBuilder;
@@ -23,6 +24,8 @@ import org.gradle.api.tasks.TaskFilePropertyBuilder;
 public interface TaskFilePropertyBuilderInternal extends TaskFilePropertyBuilder {
     TaskFilePropertyBuilderInternal withSnapshotNormalizationStrategy(SnapshotNormalizationStrategy snapshotNormalizationStrategy);
 
+    TaskFilePropertyBuilderInternal withSnapshotter(Class<? extends FileCollectionSnapshotter> snapshotter);
+
     @Override
     TaskFilePropertyBuilderInternal withPathSensitivity(PathSensitivity sensitivity);
 
