@@ -30,9 +30,6 @@ import org.gradle.api.internal.file.DefaultFileLookup;
 import org.gradle.api.internal.file.FileLookup;
 import org.gradle.api.internal.file.FileResolver;
 import org.gradle.api.internal.file.IdentityFileResolver;
-import org.gradle.api.internal.initialization.loadercache.ClassLoaderCache;
-import org.gradle.api.internal.initialization.loadercache.DefaultClassLoaderCache;
-import org.gradle.api.internal.initialization.loadercache.HashClassPathSnapshotter;
 import org.gradle.cache.internal.CacheFactory;
 import org.gradle.cache.internal.DefaultCacheFactory;
 import org.gradle.cache.internal.DefaultFileLockManager;
@@ -43,9 +40,6 @@ import org.gradle.initialization.DefaultClassLoaderRegistry;
 import org.gradle.initialization.DefaultCommandLineConverter;
 import org.gradle.initialization.DefaultGradleLauncherFactory;
 import org.gradle.initialization.GradleLauncherFactory;
-import org.gradle.internal.classloader.ClassLoaderFactory;
-import org.gradle.internal.classloader.ClassPathSnapshotter;
-import org.gradle.internal.classloader.DefaultHashingClassLoaderFactory;
 import org.gradle.internal.concurrent.DefaultExecutorFactory;
 import org.gradle.internal.concurrent.ExecutorFactory;
 import org.gradle.internal.event.DefaultListenerManager;
@@ -61,6 +55,11 @@ import org.gradle.internal.nativeintegration.filesystem.FileSystem;
 import org.gradle.internal.remote.MessagingServer;
 import org.gradle.internal.service.DefaultServiceRegistry;
 import org.gradle.internal.service.ServiceRegistry;
+import org.gradle.internal.time.TimeProvider;
+import org.gradle.internal.time.TrueTimeProvider;
+import org.gradle.process.internal.health.memory.DefaultMemoryManager;
+import org.gradle.process.internal.health.memory.MemoryInfo;
+import org.gradle.process.internal.health.memory.MemoryManager;
 import org.gradle.testfixtures.internal.NativeServicesTestFixture;
 import org.junit.Test;
 
@@ -90,7 +89,7 @@ public class GlobalScopeServicesTest {
     @Test
     public void providesCommandLineArgsConverter() {
         assertThat(registry().get(CommandLineConverter.class), instanceOf(
-                DefaultCommandLineConverter.class));
+            DefaultCommandLineConverter.class));
     }
 
     @Test
@@ -138,11 +137,6 @@ public class GlobalScopeServicesTest {
         assertThat(registry().get(CurrentGradleInstallation.class), instanceOf(CurrentGradleInstallation.class));
     }
 
-    @Test
-    public void providesAClassLoaderFactory() {
-        assertThat(registry().get(ClassLoaderFactory.class), instanceOf(DefaultHashingClassLoaderFactory.class));
-    }
-
     @Test
     public void providesAMessagingServer() {
         assertThat(registry().get(MessagingServer.class), instanceOf(MessagingServer.class));
@@ -194,14 +188,17 @@ public class GlobalScopeServicesTest {
     }
 
     @Test
-    public void providesAClasspathSnapshotter() throws Exception {
-        assertThat(registry().get(ClassPathSnapshotter.class), instanceOf(HashClassPathSnapshotter.class));
-        assertThat(longLivingProcessRegistry().get(ClassPathSnapshotter.class), instanceOf(HashClassPathSnapshotter.class));
+    public void providesATimeProvider() throws Exception {
+        assertThat(registry().get(TimeProvider.class), instanceOf(TrueTimeProvider.class));
     }
 
     @Test
-    public void providesAClassloaderCache() throws Exception {
-        assertThat(registry().get(ClassLoaderCache.class), instanceOf(DefaultClassLoaderCache.class));
+    public void providesAMemoryInfo() throws Exception {
+        assertThat(registry().get(MemoryInfo.class), instanceOf(MemoryInfo.class));
     }
 
+    @Test
+    public void providesAMemoryManager() throws Exception {
+        assertThat(registry().get(MemoryManager.class), instanceOf(DefaultMemoryManager.class));
+    }
 }
