@@ -16,7 +16,7 @@
 
 package org.gradle.util;
 
-import org.gradle.internal.TimeProvider;
+import org.gradle.internal.time.TimeProvider;
 
 public class MockTimeProvider implements TimeProvider {
 
@@ -40,4 +40,10 @@ public class MockTimeProvider implements TimeProvider {
         current += 10L;
         return current;
     }
+
+    /** Increments the time by 10ms and returns it. */
+    @Override
+    public long getCurrentTimeForDuration() {
+        return getCurrentTime();
+    }
 }
