@@ -15,9 +15,12 @@
  */
 package org.gradle.api.internal.artifacts;
 
-import org.gradle.api.artifacts.ResolveContext;
-import org.gradle.api.artifacts.ResolveException;
+import org.gradle.api.attributes.AttributesSchema;
+import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.DependencyGraphVisitor;
+import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.DependencyArtifactsVisitor;
 import org.gradle.api.internal.artifacts.repositories.ResolutionAwareRepository;
+import org.gradle.api.specs.Spec;
+import org.gradle.internal.component.model.DependencyMetadata;
 
 import java.util.List;
 
@@ -25,10 +28,8 @@ public interface ArtifactDependencyResolver {
     void resolve(ResolveContext resolveContext,
                  List<? extends ResolutionAwareRepository> repositories,
                  GlobalDependencyResolutionRules metadataHandler,
-                 ResolverResults results) throws ResolveException;
-
-    void resolveArtifacts(ResolveContext resolveContext,
-                 List<? extends ResolutionAwareRepository> repositories,
-                 GlobalDependencyResolutionRules metadataHandler,
-                 ResolverResults results) throws ResolveException;
+                 Spec<? super DependencyMetadata> edgeFilter,
+                 DependencyGraphVisitor graphVisitor,
+                 DependencyArtifactsVisitor artifactsVisitor,
+                 AttributesSchema attributesSchema);
 }
