@@ -17,6 +17,7 @@ package org.gradle.api.internal.artifacts.configurations;
 
 import org.gradle.api.DomainObjectSet;
 import org.gradle.api.UnknownDomainObjectException;
+import org.gradle.api.artifacts.ConfigurablePublishArtifact;
 import org.gradle.api.artifacts.Configuration;
 import org.gradle.api.artifacts.Dependency;
 import org.gradle.api.artifacts.UnknownConfigurationException;
@@ -24,14 +25,19 @@ import org.gradle.api.internal.AbstractNamedDomainObjectContainer;
 import org.gradle.api.internal.DomainObjectContext;
 import org.gradle.api.internal.artifacts.ConfigurationResolver;
 import org.gradle.api.internal.artifacts.component.ComponentIdentifierFactory;
+import org.gradle.api.internal.artifacts.dsl.PublishArtifactNotationParserFactory;
 import org.gradle.api.internal.artifacts.dsl.dependencies.ProjectFinder;
 import org.gradle.api.internal.artifacts.ivyservice.dependencysubstitution.DependencySubstitutionRules;
 import org.gradle.api.internal.artifacts.ivyservice.moduleconverter.ConfigurationComponentMetaDataBuilder;
 import org.gradle.api.internal.artifacts.ivyservice.resolutionstrategy.DefaultResolutionStrategy;
+import org.gradle.api.internal.attributes.ImmutableAttributesFactory;
 import org.gradle.api.internal.file.FileCollectionFactory;
+import org.gradle.api.internal.tasks.TaskResolver;
 import org.gradle.initialization.ProjectAccessListener;
 import org.gradle.internal.event.ListenerManager;
+import org.gradle.internal.progress.BuildOperationExecutor;
 import org.gradle.internal.reflect.Instantiator;
+import org.gradle.internal.typeconversion.NotationParser;
 
 import java.util.Collection;
 import java.util.Set;
@@ -51,6 +57,9 @@ public class DefaultConfigurationContainer extends AbstractNamedDomainObjectCont
     private final FileCollectionFactory fileCollectionFactory;
     private final DependencySubstitutionRules globalDependencySubstitutionRules;
     private final ComponentIdentifierFactory componentIdentifierFactory;
+    private final BuildOperationExecutor buildOperationExecutor;
+    private final NotationParser<Object, ConfigurablePublishArtifact> artifactNotationParser;
+    private final ImmutableAttributesFactory attributesFactory;
 
     private int detachedConfigurationDefaultNameCounter = 1;
 
@@ -59,7 +68,9 @@ public class DefaultConfigurationContainer extends AbstractNamedDomainObjectCont
                                          DependencyMetaDataProvider dependencyMetaDataProvider, ProjectAccessListener projectAccessListener,
                                          ProjectFinder projectFinder, ConfigurationComponentMetaDataBuilder configurationComponentMetaDataBuilder,
                                          FileCollectionFactory fileCollectionFactory, DependencySubstitutionRules globalDependencySubstitutionRules,
-                                         ComponentIdentifierFactory componentIdentifierFactory) {
+                                         ComponentIdentifierFactory componentIdentifierFactory, BuildOperationExecutor buildOperationExecutor,
+                                         TaskResolver taskResolver,
+                                         ImmutableAttributesFactory attributesFactory) {
         super(Configuration.class, instantiator, new Configuration.Namer());
         this.resolver = resolver;
         this.instantiator = instantiator;
@@ -72,18 +83,21 @@ public class DefaultConfigurationContainer extends AbstractNamedDomainObjectCont
         this.fileCollectionFactory = fileCollectionFactory;
         this.globalDependencySubstitutionRules = globalDependencySubstitutionRules;
         this.componentIdentifierFactory = componentIdentifierFactory;
+        this.buildOperationExecutor = buildOperationExecutor;
+        this.artifactNotationParser = new PublishArtifactNotationParserFactory(instantiator, dependencyMetaDataProvider, taskResolver).create();
+        this.attributesFactory = attributesFactory;
     }
 
     @Override
     protected Configuration doCreate(String name) {
         DefaultResolutionStrategy resolutionStrategy = instantiator.newInstance(DefaultResolutionStrategy.class, globalDependencySubstitutionRules, componentIdentifierFactory);
-        return instantiator.newInstance(DefaultConfiguration.class, context.absoluteProjectPath(name), name, this, resolver,
+        return instantiator.newInstance(DefaultConfiguration.class, context.identityPath(name), context.projectPath(name), name, this, resolver,
                 listenerManager, dependencyMetaDataProvider, resolutionStrategy, projectAccessListener, projectFinder,
-                configurationComponentMetaDataBuilder, fileCollectionFactory, componentIdentifierFactory);
+                configurationComponentMetaDataBuilder, fileCollectionFactory, componentIdentifierFactory, buildOperationExecutor, instantiator, artifactNotationParser, attributesFactory);
     }
 
-    public Set<Configuration> getAll() {
-        return this;
+    public Set<? extends ConfigurationInternal> getAll() {
+        return withType(ConfigurationInternal.class);
     }
 
     @Override
@@ -104,10 +118,10 @@ public class DefaultConfigurationContainer extends AbstractNamedDomainObjectCont
     public ConfigurationInternal detachedConfiguration(Dependency... dependencies) {
         String name = DETACHED_CONFIGURATION_DEFAULT_NAME + detachedConfigurationDefaultNameCounter++;
         DetachedConfigurationsProvider detachedConfigurationsProvider = new DetachedConfigurationsProvider();
-        DefaultConfiguration detachedConfiguration = new DefaultConfiguration(
-                name, name, detachedConfigurationsProvider, resolver,
+        DefaultConfiguration detachedConfiguration = instantiator.newInstance(DefaultConfiguration.class,
+                context.identityPath(name), context.projectPath(name), name, detachedConfigurationsProvider, resolver,
                 listenerManager, dependencyMetaDataProvider, new DefaultResolutionStrategy(globalDependencySubstitutionRules, componentIdentifierFactory), projectAccessListener, projectFinder,
-                configurationComponentMetaDataBuilder, fileCollectionFactory, componentIdentifierFactory);
+                configurationComponentMetaDataBuilder, fileCollectionFactory, componentIdentifierFactory, buildOperationExecutor, instantiator, artifactNotationParser, attributesFactory);
         DomainObjectSet<Dependency> detachedDependencies = detachedConfiguration.getDependencies();
         for (Dependency dependency : dependencies) {
             detachedDependencies.add(dependency.copy());
@@ -124,7 +138,7 @@ public class DefaultConfigurationContainer extends AbstractNamedDomainObjectCont
         StringBuilder reply = new StringBuilder();
 
         reply.append("Configuration of type: " + getTypeDisplayName());
-        Collection<Configuration> configs = getAll();
+        Collection<? extends Configuration> configs = getAll();
         for (Configuration c : configs) {
             reply.append("\n  " + c.toString());
         }
