@@ -19,6 +19,8 @@ package org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.DependencyGraphNode;
 
 public interface DependencyArtifactsVisitor {
-    void visitArtifacts(DependencyGraphNode parent, DependencyGraphNode child, ArtifactSet artifacts);
+    // TODO:DAZ Performing the topo-sort for nodes shouldn't be done in a DependencyArtifactsVisitor
+    void startArtifacts(DependencyGraphNode root);
+    void visitArtifacts(DependencyGraphNode from, DependencyGraphNode to, ArtifactSet artifacts);
     void finishArtifacts();
 }
