@@ -23,6 +23,7 @@ import org.gradle.api.artifacts.ModuleVersionSelector;
 import org.gradle.api.artifacts.component.ComponentIdentifier;
 import org.gradle.api.artifacts.component.ComponentSelector;
 import org.gradle.api.artifacts.result.ComponentSelectionReason;
+import org.gradle.api.attributes.AttributesSchema;
 import org.gradle.api.internal.artifacts.DefaultModuleIdentifier;
 import org.gradle.api.internal.artifacts.ResolveContext;
 import org.gradle.api.internal.artifacts.ResolvedConfigurationIdentifier;
@@ -35,6 +36,7 @@ import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.conflict
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.conflicts.ConflictResolutionResult;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph.conflicts.PotentialConflict;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.result.VersionSelectionReasons;
+import org.gradle.api.specs.Spec;
 import org.gradle.internal.component.local.model.DslOriginDependencyMetadata;
 import org.gradle.internal.component.model.ComponentArtifactMetadata;
 import org.gradle.internal.component.model.ComponentResolveMetadata;
@@ -68,17 +70,21 @@ import java.util.Set;
 public class DependencyGraphBuilder {
     private static final Logger LOGGER = LoggerFactory.getLogger(DependencyGraphBuilder.class);
     private final ConflictHandler conflictHandler;
+    private final Spec<? super DependencyMetadata> edgeFilter;
     private final ResolveContextToComponentResolver moduleResolver;
     private final DependencyToComponentIdResolver idResolver;
     private final ComponentMetaDataResolver metaDataResolver;
+    private final AttributesSchema attributesSchema;
 
     public DependencyGraphBuilder(DependencyToComponentIdResolver componentIdResolver, ComponentMetaDataResolver componentMetaDataResolver,
                                   ResolveContextToComponentResolver resolveContextToComponentResolver,
-                                  ConflictHandler conflictHandler) {
+                                  ConflictHandler conflictHandler, Spec<? super DependencyMetadata> edgeFilter, AttributesSchema attributesSchema) {
         this.idResolver = componentIdResolver;
         this.metaDataResolver = componentMetaDataResolver;
         this.moduleResolver = resolveContextToComponentResolver;
         this.conflictHandler = conflictHandler;
+        this.edgeFilter = edgeFilter;
+        this.attributesSchema = attributesSchema;
     }
 
     public void resolve(ResolveContext resolveContext, DependencyGraphVisitor modelVisitor) {
@@ -86,7 +92,7 @@ public class DependencyGraphBuilder {
         DefaultBuildableComponentResolveResult rootModule = new DefaultBuildableComponentResolveResult();
         moduleResolver.resolve(resolveContext, rootModule);
 
-        ResolveState resolveState = new ResolveState(idGenerator, rootModule, resolveContext.getName(), idResolver, metaDataResolver);
+        ResolveState resolveState = new ResolveState(idGenerator, rootModule, resolveContext.getName(), idResolver, metaDataResolver, edgeFilter, attributesSchema);
         conflictHandler.registerResolver(new DirectDependencyForcingResolver(resolveState.root.moduleRevision));
 
         traverseGraph(resolveState, conflictHandler);
@@ -175,23 +181,29 @@ public class DependencyGraphBuilder {
     /**
      * Populates the result from the graph traversal state.
      */
-    private void assembleResult(ResolveState resolveState, DependencyGraphVisitor listener) {
-        listener.start(resolveState.root);
+    private void assembleResult(ResolveState resolveState, DependencyGraphVisitor visitor) {
+        visitor.start(resolveState.root);
 
         // Visit the nodes
         for (ConfigurationNode resolvedConfiguration : resolveState.getConfigurationNodes()) {
             if (resolvedConfiguration.isSelected()) {
-                listener.visitNode(resolvedConfiguration);
-            }
-        }
-        // Visit the edges
-        for (ConfigurationNode resolvedConfiguration : resolveState.getConfigurationNodes()) {
-            if (resolvedConfiguration.isSelected()) {
-                listener.visitEdge(resolvedConfiguration);
+                visitor.visitNode(resolvedConfiguration);
             }
         }
 
-        listener.finish(resolveState.root);
+        // Visit the selectors
+        for (DependencyGraphSelector selector : resolveState.getSelectors()) {
+            visitor.visitSelector(selector);
+        }
+
+        // Visit the edges
+        for (ConfigurationNode resolvedConfiguration : resolveState.getConfigurationNodes()) {
+            if (resolvedConfiguration.isSelected()) {
+                visitor.visitEdges(resolvedConfiguration);
+            }
+        }
+
+        visitor.finish(resolveState.root);  
     }
 
     /**
@@ -225,6 +237,11 @@ public class DependencyGraphBuilder {
             return from;
         }
 
+        @Override
+        public DependencyGraphSelector getSelector() {
+            return selector;
+        }
+
         /**
          * @return The resolved module version
          */
@@ -277,9 +294,9 @@ public class DependencyGraphBuilder {
                 return;
             }
 
-            Set<ConfigurationMetadata> targetConfigurations = dependencyMetadata.selectConfigurations(from.moduleRevision.metaData, from.metaData, targetModuleVersion);
+            Set<ConfigurationMetadata> targetConfigurations = dependencyMetadata.selectConfigurations(from.moduleRevision.metaData, from.metaData, targetModuleVersion, resolveState.getAttributesSchema());
             for (ConfigurationMetadata targetConfiguration : targetConfigurations) {
-                ConfigurationNode targetConfigurationNode = resolveState.getConfigurationNode(targetModuleRevision, targetConfiguration.getName());
+                ConfigurationNode targetConfigurationNode = resolveState.getConfigurationNode(targetModuleRevision, targetConfiguration);
                 this.targetConfigurations.add(targetConfigurationNode);
             }
         }
@@ -323,6 +340,11 @@ public class DependencyGraphBuilder {
             return null;
         }
 
+        @Override
+        public Iterable<? extends DependencyGraphNode> getTargets() {
+            return targetConfigurations;
+        }
+
         @Override
         public Set<ComponentArtifactMetadata> getArtifacts(ConfigurationMetadata metaData1) {
             return dependencyMetadata.getArtifacts(from.metaData, metaData1);
@@ -333,6 +355,7 @@ public class DependencyGraphBuilder {
      * Global resolution state.
      */
     private static class ResolveState {
+        private final Spec<? super DependencyMetadata> edgeFilter;
         private final Map<ModuleIdentifier, ModuleResolveState> modules = new LinkedHashMap<ModuleIdentifier, ModuleResolveState>();
         private final Map<ResolvedConfigurationIdentifier, ConfigurationNode> nodes = new LinkedHashMap<ResolvedConfigurationIdentifier, ConfigurationNode>();
         private final Map<ModuleVersionSelector, ModuleVersionSelectorResolveState> selectors = new LinkedHashMap<ModuleVersionSelector, ModuleVersionSelectorResolveState>();
@@ -342,12 +365,15 @@ public class DependencyGraphBuilder {
         private final ComponentMetaDataResolver metaDataResolver;
         private final Set<ConfigurationNode> queued = new HashSet<ConfigurationNode>();
         private final LinkedList<ConfigurationNode> queue = new LinkedList<ConfigurationNode>();
+        private final AttributesSchema attributesSchema;
 
         public ResolveState(IdGenerator<Long> idGenerator, ComponentResolveResult rootResult, String rootConfigurationName, DependencyToComponentIdResolver idResolver,
-                            ComponentMetaDataResolver metaDataResolver) {
+                            ComponentMetaDataResolver metaDataResolver, Spec<? super DependencyMetadata> edgeFilter, AttributesSchema attributesSchema) {
             this.idGenerator = idGenerator;
             this.idResolver = idResolver;
             this.metaDataResolver = metaDataResolver;
+            this.edgeFilter = edgeFilter;
+            this.attributesSchema = attributesSchema;
             ModuleVersionResolveState rootVersion = getRevision(rootResult.getId());
             rootVersion.setMetaData(rootResult.getMetaData());
             root = new RootConfigurationNode(idGenerator.generateId(), rootVersion, new ResolvedConfigurationIdentifier(rootVersion.id, rootConfigurationName), this);
@@ -372,21 +398,25 @@ public class DependencyGraphBuilder {
             return nodes.values();
         }
 
-        public ConfigurationNode getConfigurationNode(ModuleVersionResolveState module, String configurationName) {
-            ResolvedConfigurationIdentifier id = new ResolvedConfigurationIdentifier(module.id, configurationName);
+        public ConfigurationNode getConfigurationNode(ModuleVersionResolveState module, ConfigurationMetadata configurationMetadata) {
+            ResolvedConfigurationIdentifier id = new ResolvedConfigurationIdentifier(module.id, configurationMetadata.getName());
             ConfigurationNode configuration = nodes.get(id);
             if (configuration == null) {
-                configuration = new ConfigurationNode(idGenerator.generateId(), id, module, this);
+                configuration = new ConfigurationNode(idGenerator.generateId(), id, module, this, configurationMetadata);
                 nodes.put(id, configuration);
             }
             return configuration;
         }
 
+        public Collection<ModuleVersionSelectorResolveState> getSelectors() {
+            return selectors.values();
+        }
+
         public ModuleVersionSelectorResolveState getSelector(DependencyMetadata dependencyMetadata) {
             ModuleVersionSelector requested = dependencyMetadata.getRequested();
             ModuleVersionSelectorResolveState resolveState = selectors.get(requested);
             if (resolveState == null) {
-                resolveState = new ModuleVersionSelectorResolveState(dependencyMetadata, idResolver, this);
+                resolveState = new ModuleVersionSelectorResolveState(idGenerator.generateId(), dependencyMetadata, idResolver, this);
                 selectors.put(requested, resolveState);
             }
             return resolveState;
@@ -422,6 +452,10 @@ public class DependencyGraphBuilder {
                 queue.addFirst(configuration);
             }
         }
+
+        public AttributesSchema getAttributesSchema() {
+            return attributesSchema;
+        }
     }
 
     enum ModuleState {
@@ -672,21 +706,25 @@ public class DependencyGraphBuilder {
         private ModuleExclusion previousTraversalExclusions;
 
         private ConfigurationNode(Long resultId, ResolvedConfigurationIdentifier id, ModuleVersionResolveState moduleRevision, ResolveState resolveState) {
+            this(resultId, id, moduleRevision, resolveState, moduleRevision.metaData.getConfiguration(id.getConfiguration()));
+        }
+
+        private ConfigurationNode(Long resultId, ResolvedConfigurationIdentifier id, ModuleVersionResolveState moduleRevision, ResolveState resolveState, ConfigurationMetadata md) {
             this.resultId = resultId;
             this.id = id;
             this.moduleRevision = moduleRevision;
             this.resolveState = resolveState;
-            this.metaData = moduleRevision.metaData.getConfiguration(id.getConfiguration());
+            this.metaData = md;
             moduleRevision.addConfiguration(this);
         }
 
         @Override
-        public Long getResultId() {
+        public Long getNodeId() {
             return resultId;
         }
 
         @Override
-        public ResolvedConfigurationIdentifier getNodeId() {
+        public ResolvedConfigurationIdentifier getResolvedConfigurationId() {
             return id;
         }
 
@@ -712,7 +750,7 @@ public class DependencyGraphBuilder {
 
         @Override
         public String toString() {
-            return String.format("%s(%s)", id.getId(), id.getConfiguration());
+            return String.format("%s(%s)", moduleRevision, id.getConfiguration());
         }
 
         public boolean isTransitive() {
@@ -763,8 +801,7 @@ public class DependencyGraphBuilder {
             }
 
             for (DependencyMetadata dependency : metaData.getDependencies()) {
-                ModuleIdentifier targetModuleId = DefaultModuleIdentifier.newId(dependency.getRequested().getGroup(), dependency.getRequested().getName());
-                if (isExcluded(resolutionFilter, targetModuleId)) {
+                if (isExcluded(resolutionFilter, dependency)) {
                     continue;
                 }
                 DependencyEdge dependencyEdge = new DependencyEdge(this, dependency, resolutionFilter, resolveState);
@@ -774,8 +811,13 @@ public class DependencyGraphBuilder {
             previousTraversalExclusions = resolutionFilter;
         }
 
-        private boolean isExcluded(ModuleExclusion selector, ModuleIdentifier targetModuleId) {
-            if(selector.excludeModule(targetModuleId)) {
+        private boolean isExcluded(ModuleExclusion selector, DependencyMetadata dependency) {
+            if (!resolveState.edgeFilter.isSatisfiedBy(dependency)) {
+                LOGGER.debug("{} is filtered.", dependency);
+                return true;
+            }
+            ModuleIdentifier targetModuleId = DefaultModuleIdentifier.newId(dependency.getRequested().getGroup(), dependency.getRequested().getName());
+            if (selector.excludeModule(targetModuleId)) {
                 LOGGER.debug("{} is excluded from {}.", targetModuleId, this);
                 return true;
             }
@@ -857,7 +899,8 @@ public class DependencyGraphBuilder {
     /**
      * Resolution state for a given module version selector.
      */
-    private static class ModuleVersionSelectorResolveState {
+    private static class ModuleVersionSelectorResolveState implements DependencyGraphSelector {
+        final Long id;
         final DependencyMetadata dependencyMetadata;
         final DependencyToComponentIdResolver resolver;
         final ResolveState resolveState;
@@ -866,18 +909,29 @@ public class DependencyGraphBuilder {
         ModuleVersionResolveState targetModuleRevision;
         BuildableComponentIdResolveResult idResolveResult;
 
-        private ModuleVersionSelectorResolveState(DependencyMetadata dependencyMetadata, DependencyToComponentIdResolver resolver, ResolveState resolveState) {
+        private ModuleVersionSelectorResolveState(Long id, DependencyMetadata dependencyMetadata, DependencyToComponentIdResolver resolver, ResolveState resolveState) {
+            this.id = id;
             this.dependencyMetadata = dependencyMetadata;
             this.resolver = resolver;
             this.resolveState = resolveState;
             targetModule = resolveState.getModule(new DefaultModuleIdentifier(dependencyMetadata.getRequested().getGroup(), dependencyMetadata.getRequested().getName()));
         }
 
+        @Override
+        public Long getResultId() {
+            return id;
+        }
+
         @Override
         public String toString() {
             return dependencyMetadata.toString();
         }
 
+        @Override
+        public ComponentSelector getRequested() {
+            return dependencyMetadata.getSelector();
+        }
+
         private ModuleVersionResolveException getFailure() {
             return failure != null ? failure : targetModuleRevision.getFailure();
         }
