@@ -16,26 +16,28 @@
 
 package org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph;
 
-import org.gradle.api.artifacts.ModuleVersionIdentifier;
-import org.gradle.api.artifacts.component.ComponentIdentifier;
 import org.gradle.api.internal.artifacts.ResolvedConfigurationIdentifier;
-import org.gradle.api.internal.artifacts.ivyservice.resolveengine.result.ModuleVersionSelection;
-import org.gradle.internal.component.model.ConfigurationMetaData;
+import org.gradle.internal.component.model.ConfigurationMetadata;
 
 import java.util.Set;
 
+/**
+ * A node in the dependency graph. Represents a configuration.
+ */
 public interface DependencyGraphNode {
-    ResolvedConfigurationIdentifier getNodeId();
+    /**
+     * Returns a simple id for this node, unique across all nodes in the same graph.
+     * This id cannot be used across graphs.
+     */
+    Long getNodeId();
 
-    ModuleVersionIdentifier toId();
+    ResolvedConfigurationIdentifier getResolvedConfigurationId();
 
-    ComponentIdentifier getComponentId();
+    DependencyGraphComponent getOwner();
 
-    ModuleVersionSelection getSelection();
+    Set<? extends DependencyGraphEdge> getIncomingEdges();
 
-    Set<DependencyGraphEdge> getIncomingEdges();
+    Set<? extends DependencyGraphEdge> getOutgoingEdges();
 
-    Set<DependencyGraphEdge> getOutgoingEdges();
-
-    ConfigurationMetaData getMetaData();
+    ConfigurationMetadata getMetadata();
 }
