@@ -23,22 +23,22 @@ import org.gradle.api.artifacts.component.ProjectComponentSelector;
 import org.gradle.internal.component.external.model.DefaultModuleComponentSelector;
 import org.gradle.internal.component.local.model.DefaultLibraryComponentSelector;
 import org.gradle.internal.component.local.model.DefaultProjectComponentSelector;
+import org.gradle.internal.serialize.AbstractSerializer;
 import org.gradle.internal.serialize.Decoder;
 import org.gradle.internal.serialize.Encoder;
-import org.gradle.internal.serialize.Serializer;
 
 import java.io.IOException;
 
-public class ComponentSelectorSerializer implements Serializer<ComponentSelector> {
+public class ComponentSelectorSerializer extends AbstractSerializer<ComponentSelector> {
     public ComponentSelector read(Decoder decoder) throws IOException {
         byte id = decoder.readByte();
 
         if (Implementation.BUILD.getId() == id) {
-            return new DefaultProjectComponentSelector(decoder.readString());
+            return new DefaultProjectComponentSelector(decoder.readString(), decoder.readString());
         } else if (Implementation.MODULE.getId() == id) {
             return new DefaultModuleComponentSelector(decoder.readString(), decoder.readString(), decoder.readString());
         } else if (Implementation.LIBRARY.getId() == id) {
-            return new DefaultLibraryComponentSelector(decoder.readString(), decoder.readNullableString());
+            return new DefaultLibraryComponentSelector(decoder.readString(), decoder.readNullableString(), decoder.readNullableString());
         }
 
         throw new IllegalArgumentException("Unable to find component selector with id: " + id);
@@ -49,36 +49,55 @@ public class ComponentSelectorSerializer implements Serializer<ComponentSelector
             throw new IllegalArgumentException("Provided component selector may not be null");
         }
 
-        if (value instanceof DefaultModuleComponentSelector) {
+        Implementation implementation = resolveImplementation(value);
+
+        encoder.writeByte(implementation.getId());
+
+        if (implementation == Implementation.MODULE) {
             ModuleComponentSelector moduleComponentSelector = (ModuleComponentSelector) value;
-            encoder.writeByte(Implementation.MODULE.getId());
             encoder.writeString(moduleComponentSelector.getGroup());
             encoder.writeString(moduleComponentSelector.getModule());
             encoder.writeString(moduleComponentSelector.getVersion());
-        } else if (value instanceof DefaultProjectComponentSelector) {
+        } else if (implementation == Implementation.BUILD) {
             ProjectComponentSelector projectComponentSelector = (ProjectComponentSelector) value;
-            encoder.writeByte(Implementation.BUILD.getId());
+            encoder.writeString(projectComponentSelector.getBuildName());
             encoder.writeString(projectComponentSelector.getProjectPath());
-        } else if (value instanceof DefaultLibraryComponentSelector) {
+        } else if (implementation == Implementation.LIBRARY) {
             LibraryComponentSelector libraryComponentSelector = (LibraryComponentSelector) value;
-            encoder.writeByte(Implementation.LIBRARY.getId());
             encoder.writeString(libraryComponentSelector.getProjectPath());
             encoder.writeNullableString(libraryComponentSelector.getLibraryName());
+            encoder.writeNullableString(libraryComponentSelector.getVariant());
         } else {
-            throw new IllegalArgumentException("Unsupported component selector class: " + value.getClass());
+            throw new IllegalStateException("Unsupported implementation type: " + implementation);
         }
     }
 
-    private static enum Implementation {
-        MODULE((byte) 1), BUILD((byte) 2), LIBRARY((byte) 3);
+    private ComponentSelectorSerializer.Implementation resolveImplementation(ComponentSelector value) {
+        Implementation implementation;
+
+        if (value instanceof ModuleComponentSelector) {
+            implementation = Implementation.MODULE;
+        } else if (value instanceof ProjectComponentSelector) {
+            implementation = Implementation.BUILD;
+        } else if (value instanceof LibraryComponentSelector) {
+            implementation = Implementation.LIBRARY;
+        } else {
+            throw new IllegalArgumentException("Unsupported component selector class: " + value.getClass());
+        }
+
+        return implementation;
+    }
+
+    private enum Implementation {
+        MODULE((byte) 1), BUILD((byte) 2), LIBRARY((byte) 3), BINARY((byte) 4);
 
         private final byte id;
 
-        private Implementation(byte id) {
+        Implementation(byte id) {
             this.id = id;
         }
 
-        private byte getId() {
+        byte getId() {
             return id;
         }
     }
