@@ -23,7 +23,8 @@ import org.gradle.api.internal.file.TemporaryFileProvider;
 import org.gradle.api.logging.Logger;
 import org.gradle.api.logging.Logging;
 import org.gradle.internal.concurrent.CompositeStoppable;
-import org.gradle.util.Clock;
+import org.gradle.internal.time.Timer;
+import org.gradle.internal.time.Timers;
 
 import java.io.Closeable;
 import java.io.File;
@@ -117,13 +118,13 @@ public class ResolutionResultsStoreFactory implements Closeable {
 
     public void close() {
         try {
-            Clock clock = new Clock();
+            Timer clock = Timers.startTimer();
             cleanUpLater.stop();
-            LOG.debug("Deleted {} resolution results binary files in {}", stores.size(), clock.getTime());
+            LOG.debug("Deleted {} resolution results binary files in {}", stores.size(), clock.getElapsed());
         } finally {
             oldModelCache = null;
             newModelCache = null;
             stores.clear();
         }
     }
-}
\ No newline at end of file
+}
