@@ -21,11 +21,14 @@ import org.gradle.api.internal.file.TestFiles;
 import org.gradle.internal.Factory;
 import org.gradle.internal.jvm.Jvm;
 import org.gradle.internal.os.OperatingSystem;
+import org.gradle.process.internal.AbstractExecHandleBuilder;
+import org.gradle.process.internal.DefaultExecHandleBuilder;
 import org.gradle.process.internal.ExecHandleBuilder;
 import org.gradle.process.internal.JvmOptions;
 import org.gradle.test.fixtures.file.TestDirectoryProvider;
 import org.gradle.test.fixtures.file.TestFile;
 import org.gradle.testfixtures.internal.NativeServicesTestFixture;
+import org.gradle.util.GradleVersion;
 
 import java.io.File;
 import java.util.ArrayList;
@@ -41,6 +44,14 @@ public class ForkingGradleExecuter extends AbstractGradleExecuter {
         super(distribution, testDirectoryProvider);
     }
 
+    public ForkingGradleExecuter(GradleDistribution distribution, TestDirectoryProvider testDirectoryProvider, GradleVersion version) {
+        super(distribution, testDirectoryProvider, version);
+    }
+
+    public ForkingGradleExecuter(GradleDistribution distribution, TestDirectoryProvider testDirectoryProvider, GradleVersion gradleVersion, IntegrationTestBuildContext buildContext) {
+        super(distribution, testDirectoryProvider, gradleVersion, buildContext);
+    }
+
     public void assertCanExecute() throws AssertionError {
         if (!getDistribution().isSupportsSpacesInGradleAndJavaOpts()) {
             Map<String, String> environmentVars = buildInvocation().environmentVars;
@@ -62,7 +73,7 @@ public class ForkingGradleExecuter extends AbstractGradleExecuter {
     protected void transformInvocation(GradleInvocation invocation) {
         if (getDistribution().isSupportsSpacesInGradleAndJavaOpts()) {
             // Mix the implicit launcher JVM args in with the requested JVM args
-            invocation.launcherJvmArgs.addAll(invocation.implicitLauncherJvmArgs);
+            super.transformInvocation(invocation);
         } else {
             // Need to move those implicit JVM args that contain a space to the Gradle command-line (if possible)
             // Note that this isn't strictly correct as some system properties can only be set on JVM start up.
@@ -110,7 +121,7 @@ public class ForkingGradleExecuter extends AbstractGradleExecuter {
     }
 
     private void addPropagatedSystemProperties(List<String> args) {
-        for (String propName : propagatedSystemProperties) {
+        for (String propName : PROPAGATED_SYSTEM_PROPERTIES) {
             String propValue = System.getProperty(propName);
             if (propValue != null) {
                 args.add("-D" + propName + "=" + propValue);
@@ -130,8 +141,7 @@ public class ForkingGradleExecuter extends AbstractGradleExecuter {
         }
     }
 
-
-    private ExecHandleBuilder createExecHandleBuilder() {
+    private DefaultExecHandleBuilder createExecHandleBuilder() {
         TestFile gradleHomeDir = getDistribution().getGradleHomeDir();
         if (!gradleHomeDir.isDirectory()) {
             fail(gradleHomeDir + " is not a directory.\n"
@@ -139,7 +149,7 @@ public class ForkingGradleExecuter extends AbstractGradleExecuter {
         }
 
         NativeServicesTestFixture.initialize();
-        ExecHandleBuilder builder = new ExecHandleBuilder(TestFiles.resolver()) {
+        DefaultExecHandleBuilder builder = new DefaultExecHandleBuilder(TestFiles.resolver()) {
             @Override
             public File getWorkingDir() {
                 // Override this, so that the working directory is not canonicalised. Some int tests require that
@@ -170,15 +180,15 @@ public class ForkingGradleExecuter extends AbstractGradleExecuter {
 
     @Override
     public GradleHandle doStart() {
-        return createGradleHandle(getResultAssertion(), getDefaultCharacterEncoding(), new Factory<ExecHandleBuilder>() {
-            public ExecHandleBuilder create() {
+        return createGradleHandle(getResultAssertion(), getDefaultCharacterEncoding(), new Factory<DefaultExecHandleBuilder>() {
+            public DefaultExecHandleBuilder create() {
                 return createExecHandleBuilder();
             }
         }).start();
     }
 
-    protected ForkingGradleHandle createGradleHandle(Action<ExecutionResult> resultAssertion, String encoding, Factory<ExecHandleBuilder> execHandleFactory) {
-        return new ForkingGradleHandle(getStdinPipe(), isUseDaemon(), resultAssertion, encoding, execHandleFactory);
+    protected ForkingGradleHandle createGradleHandle(Action<ExecutionResult> resultAssertion, String encoding, Factory<? extends AbstractExecHandleBuilder> execHandleFactory) {
+        return new ForkingGradleHandle(getStdinPipe(), isUseDaemon(), resultAssertion, encoding, execHandleFactory, getDurationMeasurement());
     }
 
     protected ExecutionResult doRun() {
