@@ -18,6 +18,7 @@ package org.gradle.integtests.fixtures.executer;
 import groovy.lang.Closure;
 import groovy.lang.DelegatesTo;
 import org.gradle.api.Action;
+import org.gradle.internal.concurrent.Stoppable;
 import org.gradle.test.fixtures.file.TestDirectoryProvider;
 import org.gradle.test.fixtures.file.TestFile;
 
@@ -27,7 +28,7 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
-public interface GradleExecuter {
+public interface GradleExecuter extends Stoppable {
     /**
      * Sets the working directory to use. Defaults to the test's temporary directory.
      */
@@ -168,12 +169,36 @@ public interface GradleExecuter {
      */
     GradleExecuter withBuildJvmOpts(Iterable<String> jvmOpts);
 
+    /**
+     * Activates the build cache
+     *
+     * @return this executer
+     */
+    GradleExecuter withBuildCacheEnabled();
+
+    /**
+     * Activates the build cache for a local directory
+     *
+     * @param cacheDir the directory for the cache
+     * @return this executer
+     */
+    GradleExecuter withLocalBuildCache(File cacheDir);
 
     /**
      * Don't set temp folder explicitly.
      */
     GradleExecuter withNoExplicitTmpDir();
 
+    /**
+     * Don't set native services dir explicitly.
+     */
+    GradleExecuter withNoExplicitNativeServicesDir();
+
+    /**
+     * Disables the rendering of stack traces for deprecation logging.
+     */
+    GradleExecuter withFullDeprecationStackTraceDisabled();
+
     /**
      * Specifies that the executer should only those JVM args explicitly requested using {@link #withBuildJvmOpts(String...)} and {@link #withCommandLineGradleOpts(String...)} (where appropriate) for
      * the build JVM and not attempt to provide any others.
@@ -216,6 +241,11 @@ public interface GradleExecuter {
      */
     GradleExecuter withDaemonBaseDir(File baseDir);
 
+    /**
+     * Returns the working space for any daemons used by the builds.
+     */
+    File getDaemonBaseDir();
+
     /**
      * Requires that the build run in a separate daemon process.
      */
@@ -256,9 +286,14 @@ public interface GradleExecuter {
     TestDirectoryProvider getTestDirectoryProvider();
 
     /**
-     * Disables asserting that the execution did not trigger any deprecation warnings.
+     * Expects exactly one deprecation warning in the build output. Call multiple times to expect multiple warnings.
      */
-    GradleExecuter withDeprecationChecksDisabled();
+    GradleExecuter expectDeprecationWarning();
+
+    /**
+     * Disable deprecation warning checks.
+     */
+    GradleExecuter noDeprecationChecks();
 
     /**
      * Disables asserting that class loaders were not eagerly created, potentially leading to performance problems.
@@ -276,12 +311,12 @@ public interface GradleExecuter {
     GradleExecuter noExtraLogging();
 
     /**
-     * Requires that there is a gradle home for the execution, which in process execution does not.
+     * Requires that there is a real gradle distribution for the execution, which in-process execution does not.
      *
      * <p>Note: try to avoid using this method. It has some major drawbacks when it comes to development: 1. It requires a Gradle distribution or installation, and this will need to be rebuilt after
      * each change in order to use the test, and 2. it requires that the build run in a different JVM, which makes it very difficult to debug.</p>
      */
-    GradleExecuter requireGradleHome();
+    GradleExecuter requireGradleDistribution();
 
     /**
      * Configures that any daemons used by the execution are unique to the test.
@@ -292,6 +327,11 @@ public interface GradleExecuter {
      */
     GradleExecuter requireIsolatedDaemons();
 
+    /**
+     * Returns true if this executer will share daemons with other executers.
+     */
+    boolean usesSharedDaemons();
+
     /**
      * Configures a unique gradle user home dir for the test.
      *
@@ -321,12 +361,10 @@ public interface GradleExecuter {
      */
     GradleExecuter copyTo(GradleExecuter executer);
 
-    GradleExecuter withDaemonStartingMessageEnabled();
-
     /**
      * Where possible, starts the Gradle build process in suspended debug mode.
      */
-    GradleExecuter withDebug(boolean flag);
+    GradleExecuter startBuildProcessInDebugger(boolean flag);
 
     GradleExecuter withProfiler(String profilerArg);
 
@@ -338,4 +376,26 @@ public interface GradleExecuter {
     boolean isDebug();
 
     boolean isProfile();
+
+    /**
+     * Starts the launcher JVM (daemon client) in suspended debug mode
+     */
+    GradleExecuter startLauncherInDebugger(boolean debugLauncher);
+
+    boolean isDebugLauncher();
+
+    /**
+     * Clears previous settings so that instance can be reused
+     */
+    GradleExecuter reset();
+
+    /**
+     * Measures the duration of the execution
+     */
+    GradleExecuter withDurationMeasurement(DurationMeasurement durationMeasurement);
+
+    /**
+     * Returns true if this executer uses a daemon
+     */
+    boolean isUseDaemon();
 }
