@@ -15,53 +15,103 @@
  */
 package org.gradle.integtests.fixtures.executer;
 
+import com.google.common.io.CharSource;
 import org.apache.commons.collections.CollectionUtils;
 import org.gradle.api.Action;
+import org.gradle.api.UncheckedIOException;
+import org.gradle.launcher.daemon.client.DaemonStartupMessage;
+import org.gradle.launcher.daemon.server.DaemonStateCoordinator;
 import org.gradle.util.TextUtil;
+import org.hamcrest.core.StringContains;
 
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.StringReader;
-import java.util.*;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.HashSet;
+import java.util.LinkedList;
+import java.util.List;
+import java.util.Set;
 import java.util.regex.Pattern;
 
 import static org.gradle.util.TextUtil.normaliseLineSeparators;
-import static org.hamcrest.Matchers.*;
+import static org.hamcrest.Matchers.equalTo;
+import static org.hamcrest.Matchers.hasItem;
 import static org.junit.Assert.assertThat;
 
 public class OutputScrapingExecutionResult implements ExecutionResult {
+    static final Pattern STACK_TRACE_ELEMENT = Pattern.compile("\\s+(at\\s+)?[\\w.$_]+\\.[\\w$_ =\\+\'-]+\\(.+?\\)");
     private final String output;
     private final String error;
 
+    private static final String TASK_LOGGER_DEBUG_PATTERN = "(?:.*\\s+\\[LIFECYCLE\\]\\s+\\[class org\\.gradle\\.TaskExecutionLogger\\]\\s+)?";
+
     //for example: ':a SKIPPED' or ':foo:bar:baz UP-TO-DATE' but not ':a'
-    private final Pattern skippedTaskPattern = Pattern.compile("(:\\S+?(:\\S+?)*)\\s+((SKIPPED)|(UP-TO-DATE))");
+    private final Pattern skippedTaskPattern = Pattern.compile(TASK_LOGGER_DEBUG_PATTERN + "(:\\S+?(:\\S+?)*)\\s+((SKIPPED)|(UP-TO-DATE)|(NO-SOURCE)|(FROM-CACHE))");
 
     //for example: ':hey' or ':a SKIPPED' or ':foo:bar:baz UP-TO-DATE' but not ':a FOO'
-    private final Pattern taskPattern = Pattern.compile("(:\\S+?(:\\S+?)*)((\\s+SKIPPED)|(\\s+UP-TO-DATE)|(\\s+FAILED)|(\\s*))");
+    private final Pattern taskPattern = Pattern.compile(TASK_LOGGER_DEBUG_PATTERN + "(:\\S+?(:\\S+?)*)((\\s+SKIPPED)|(\\s+UP-TO-DATE)|(\\s+FROM-CACHE)|(\\s+NO-SOURCE)|(\\s+FAILED)|(\\s*))");
 
     public OutputScrapingExecutionResult(String output, String error) {
-        this.output = output;
-        this.error = error;
+        this.output = TextUtil.normaliseLineSeparators(output);
+        this.error = TextUtil.normaliseLineSeparators(error);
     }
 
     public String getOutput() {
-        return TextUtil.normaliseLineSeparators(output);
+        return output;
+    }
+
+    @Override
+    public String getNormalizedOutput() {
+        return normalize(output);
+    }
+
+    public static String normalize(String output) {
+        StringBuilder result = new StringBuilder();
+        List<String> lines;
+        try {
+            lines = CharSource.wrap(output).readLines();
+        } catch (IOException e) {
+            throw new UncheckedIOException(e);
+        }
+        int i = 0;
+        while (i < lines.size()) {
+            String line = lines.get(i);
+            if (line.contains(DaemonStartupMessage.STARTING_DAEMON_MESSAGE)) {
+                // Remove the "daemon starting" message
+                i++;
+            } else if (line.contains(DaemonStateCoordinator.DAEMON_WILL_STOP_MESSAGE)) {
+                // Remove the "Daemon will be shut down" message
+                i++;
+            } else if (i == lines.size() - 1 && line.matches("Total time: [\\d\\.]+ secs")) {
+                result.append("Total time: 1 secs");
+                result.append('\n');
+                i++;
+            } else {
+                result.append(line);
+                result.append('\n');
+                i++;
+            }
+        }
+
+        return result.toString();
     }
 
     public ExecutionResult assertOutputEquals(String expectedOutput, boolean ignoreExtraLines, boolean ignoreLineOrder) {
         SequentialOutputMatcher matcher = ignoreLineOrder ? new AnyOrderOutputMatcher() : new SequentialOutputMatcher();
-        matcher.assertOutputMatches(expectedOutput, getOutput(), ignoreExtraLines);
+        matcher.assertOutputMatches(expectedOutput, getNormalizedOutput(), ignoreExtraLines);
         return this;
     }
 
     @Override
     public ExecutionResult assertOutputContains(String expectedOutput) {
-        assertThat("Substring not found in build output", getOutput(), org.hamcrest.core.StringContains.containsString(normaliseLineSeparators(expectedOutput)));
+        assertThat("Substring not found in build output", getOutput(), StringContains.containsString(normaliseLineSeparators(expectedOutput)));
         return this;
     }
 
     public String getError() {
-        return TextUtil.normaliseLineSeparators(error);
+        return error;
     }
 
     public List<String> getExecutedTasks() {
@@ -117,7 +167,7 @@ public class OutputScrapingExecutionResult implements ExecutionResult {
                 java.util.regex.Matcher matcher = pattern.matcher(s);
                 if (matcher.matches()) {
                     String taskName = matcher.group(1);
-                    if (!taskName.startsWith(":buildSrc:")) {
+                    if (!taskName.contains(":buildSrc:")) {
                         //for INFO/DEBUG level the task may appear twice - once for the execution, once for the UP-TO-DATE
                         //so I'm not adding the task to the list if it is the same as previously added task.
                         if (tasks.size() == 0 || !tasks.getLast().equals(taskName)) {
