@@ -17,7 +17,6 @@
 package org.gradle.test.fixtures.file;
 
 import org.junit.runners.model.FrameworkMethod;
-import org.junit.runners.model.Statement;
 
 import java.io.File;
 
@@ -27,10 +26,6 @@ public class TestDistributionDirectoryProvider extends AbstractTestDirectoryProv
         root = new TestFile(new File("build/tmp/test distros"));
     }
 
-    public Statement apply(final Statement base, final FrameworkMethod method, final Object target) {
-        return doApply(base, method, target);
-    }
-
     public static TestDistributionDirectoryProvider newInstance() {
         return new TestDistributionDirectoryProvider();
     }
@@ -41,4 +36,4 @@ public class TestDistributionDirectoryProvider extends AbstractTestDirectoryProv
         return testDirectoryProvider;
     }
 
-}
\ No newline at end of file
+}
