@@ -23,12 +23,11 @@ import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.parser.Descriptor
 import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.parser.DisconnectedDescriptorParseContext;
 import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.parser.DisconnectedIvyXmlModuleDescriptorParser;
 import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.parser.MetaDataParseException;
-import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.ResolverStrategy;
-import org.gradle.internal.component.external.model.MutableModuleComponentResolveMetaData;
 import org.gradle.api.internal.artifacts.repositories.PublicationAwareRepository;
 import org.gradle.api.publish.internal.PublicationFieldValidator;
 import org.gradle.api.publish.ivy.InvalidIvyPublicationException;
 import org.gradle.api.publish.ivy.IvyArtifact;
+import org.gradle.internal.component.external.model.MutableModuleComponentResolveMetadata;
 
 import java.io.File;
 import java.util.HashSet;
@@ -37,7 +36,7 @@ import java.util.Set;
 public class ValidatingIvyPublisher implements IvyPublisher {
     private final DescriptorParseContext parserSettings = new DisconnectedDescriptorParseContext();
     private final IvyPublisher delegate;
-    private final DisconnectedIvyXmlModuleDescriptorParser moduleDescriptorParser = new DisconnectedIvyXmlModuleDescriptorParser(new ResolverStrategy());
+    private final DisconnectedIvyXmlModuleDescriptorParser moduleDescriptorParser = new DisconnectedIvyXmlModuleDescriptorParser();
 
     public ValidatingIvyPublisher(IvyPublisher delegate) {
         this.delegate = delegate;
@@ -63,13 +62,13 @@ public class ValidatingIvyPublisher implements IvyPublisher {
                 .notEmpty()
                 .validInFileName();
 
-        MutableModuleComponentResolveMetaData metadata = parseIvyFile(publication);
+        MutableModuleComponentResolveMetadata metadata = parseIvyFile(publication);
         ModuleVersionIdentifier moduleId = metadata.getId();
         organisation.matches(moduleId.getGroup());
         moduleName.matches(moduleId.getName());
         revision.matches(moduleId.getVersion());
 
-        field(publication, "branch", metadata.getDescriptor().getModuleRevisionId().getBranch())
+        field(publication, "branch", metadata.getDescriptor().getBranch())
                 .optionalNotEmpty()
                 .doesNotContainSpecialCharacters(true);
 
@@ -78,7 +77,7 @@ public class ValidatingIvyPublisher implements IvyPublisher {
                 .validInFileName();
     }
 
-    private MutableModuleComponentResolveMetaData parseIvyFile(IvyNormalizedPublication publication) {
+    private MutableModuleComponentResolveMetadata parseIvyFile(IvyNormalizedPublication publication) {
         try {
             return moduleDescriptorParser.parseMetaData(parserSettings, publication.getDescriptorFile());
         } catch (MetaDataParseException pe) {
