@@ -36,7 +36,7 @@ public class JavaCompilerArgumentsBuilder {
     private boolean includeMainOptions = true;
     private boolean includeClasspath = true;
     private boolean includeSourceFiles;
-    private boolean includeCustomizations = true;
+    private boolean noEmptySourcePath;
 
     private List<String> args;
 
@@ -64,8 +64,8 @@ public class JavaCompilerArgumentsBuilder {
         return this;
     }
 
-    public JavaCompilerArgumentsBuilder includeCustomizations(boolean flag) {
-        includeCustomizations = flag;
+    public JavaCompilerArgumentsBuilder noEmptySourcePath() {
+        noEmptySourcePath = true;
         return this;
     }
 
@@ -75,26 +75,12 @@ public class JavaCompilerArgumentsBuilder {
         addLauncherOptions();
         addMainOptions();
         addClasspath();
+        addUserProvidedArgs();
         addSourceFiles();
-        addCustomizations();
 
         return args;
     }
 
-    private void addCustomizations() {
-        if (includeCustomizations) {
-            /*This is an internal option, it's used in com.sun.tools.javac.util.Names#createTable(Options options). The -XD backdoor switch is used to set it, as described in a comment
-            in com.sun.tools.javac.main.RecognizedOptions#getAll(OptionHelper helper). This option was introduced in JDK 7 and controls if compiler's name tables should be reused.
-            Without this option being set they are stored in a static list using soft references which can lead to memory pressure and performance deterioration
-            when using the daemon, especially when using small heap and building a large project.
-            Due to a bug (https://builds.gradle.org/viewLog.html?buildId=284033&tab=buildResultsDiv&buildTypeId=Gradle_Master_Performance_PerformanceExperimentsLinux) no instances of
-            SharedNameTable are actually ever reused. It has been fixed for JDK9 and we should consider not using this option with JDK9 as not using it  will quite probably improve the
-            performance of compilation.
-            Using this option leads to significant performance improvements when using daemon and compiling java sources with JDK7 and JDK8.*/
-            args.add(USE_UNSHARED_COMPILER_TABLE_OPTION);
-        }
-    }
-
     private void addLauncherOptions() {
         if (!includeLauncherOptions) {
             return;
@@ -117,22 +103,25 @@ public class JavaCompilerArgumentsBuilder {
             return;
         }
 
-        String sourceCompatibility = spec.getSourceCompatibility();
-        if (sourceCompatibility != null && !JavaVersion.current().equals(JavaVersion.toVersion(sourceCompatibility))) {
-            args.add("-source");
-            args.add(sourceCompatibility);
-        }
-        String targetCompatibility = spec.getTargetCompatibility();
-        if (targetCompatibility != null && !JavaVersion.current().equals(JavaVersion.toVersion(targetCompatibility))) {
-            args.add("-target");
-            args.add(targetCompatibility);
+        CompileOptions compileOptions = spec.getCompileOptions();
+        List<String> compilerArgs = compileOptions.getCompilerArgs();
+        if (!releaseOptionIsSet(compilerArgs)) {
+            String sourceCompatibility = spec.getSourceCompatibility();
+            if (sourceCompatibility != null) {
+                args.add("-source");
+                args.add(sourceCompatibility);
+            }
+            String targetCompatibility = spec.getTargetCompatibility();
+            if (targetCompatibility != null) {
+                args.add("-target");
+                args.add(targetCompatibility);
+            }
         }
         File destinationDir = spec.getDestinationDir();
         if (destinationDir != null) {
             args.add("-d");
             args.add(destinationDir.getPath());
         }
-        CompileOptions compileOptions = spec.getCompileOptions();
         if (compileOptions.isVerbose()) {
             args.add("-verbose");
         }
@@ -142,15 +131,6 @@ public class JavaCompilerArgumentsBuilder {
         if (!compileOptions.isWarnings()) {
             args.add("-nowarn");
         }
-        if (compileOptions.isDebug()) {
-            if (compileOptions.getDebugOptions().getDebugLevel() != null) {
-                args.add("-g:" + compileOptions.getDebugOptions().getDebugLevel().trim());
-            } else {
-                args.add("-g");
-            }
-        } else {
-            args.add("-g:none");
-        }
         if (compileOptions.getEncoding() != null) {
             args.add("-encoding");
             args.add(compileOptions.getEncoding());
@@ -163,21 +143,57 @@ public class JavaCompilerArgumentsBuilder {
             args.add("-extdirs");
             args.add(compileOptions.getExtensionDirs());
         }
-        FileCollection sourcepath = compileOptions.getSourcepath();
-        Iterable<File> classpath = spec.getClasspath();
-        if ((sourcepath != null && !sourcepath.isEmpty()) || (includeClasspath && (classpath != null && classpath.iterator().hasNext()))) {
-            args.add("-sourcepath");
-            args.add(sourcepath == null ? emptyFolder(spec.getTempDir()) : sourcepath.getAsPath());
+
+        if (compileOptions.isDebug()) {
+            if (compileOptions.getDebugOptions().getDebugLevel() != null) {
+                args.add("-g:" + compileOptions.getDebugOptions().getDebugLevel().trim());
+            } else {
+                args.add("-g");
+            }
+        } else {
+            args.add("-g:none");
         }
-        if (compileOptions.getCompilerArgs() != null) {
-            args.addAll(compileOptions.getCompilerArgs());
+
+        FileCollection sourcepath = compileOptions.getSourcepath();
+        if (!noEmptySourcePath || sourcepath != null && sourcepath.isEmpty()) {
+            args.add("-sourcepath");
+            args.add(sourcepath == null ? "" : sourcepath.getAsPath());
+        }
+
+        if (spec.getSourceCompatibility() == null || JavaVersion.toVersion(spec.getSourceCompatibility()).compareTo(JavaVersion.VERSION_1_6) >= 0) {
+            List<File> annotationProcessorPath = spec.getAnnotationProcessorPath();
+            if (annotationProcessorPath == null || annotationProcessorPath.isEmpty()) {
+                args.add("-proc:none");
+            } else {
+                args.add("-processorpath");
+                args.add(Joiner.on(File.pathSeparator).join(annotationProcessorPath));
+            }
+        }
+
+        /*This is an internal option, it's used in com.sun.tools.javac.util.Names#createTable(Options options). The -XD backdoor switch is used to set it, as described in a comment
+        in com.sun.tools.javac.main.RecognizedOptions#getAll(OptionHelper helper). This option was introduced in JDK 7 and controls if compiler's name tables should be reused.
+        Without this option being set they are stored in a static list using soft references which can lead to memory pressure and performance deterioration
+        when using the daemon, especially when using small heap and building a large project.
+        Due to a bug (https://builds.gradle.org/viewLog.html?buildId=284033&tab=buildResultsDiv&buildTypeId=Gradle_Master_Performance_PerformanceExperimentsLinux) no instances of
+        SharedNameTable are actually ever reused. It has been fixed for JDK9 and we should consider not using this option with JDK9 as not using it  will quite probably improve the
+        performance of compilation.
+        Using this option leads to significant performance improvements when using daemon and compiling java sources with JDK7 and JDK8.*/
+        args.add(USE_UNSHARED_COMPILER_TABLE_OPTION);
+    }
+
+    private void addUserProvidedArgs() {
+        if (!includeMainOptions) {
+            return;
+        }
+
+        List<String> compilerArgs = spec.getCompileOptions().getCompilerArgs();
+        if (compilerArgs != null) {
+            args.addAll(compilerArgs);
         }
     }
 
-    private String emptyFolder(File parent) {
-        File emptySourcePath = new File(parent, EMPTY_SOURCE_PATH_REF_DIR);
-        emptySourcePath.mkdirs();
-        return emptySourcePath.getAbsolutePath();
+    private boolean releaseOptionIsSet(List<String> compilerArgs) {
+        return compilerArgs != null && compilerArgs.contains("-release");
     }
 
     private void addClasspath() {
@@ -185,11 +201,9 @@ public class JavaCompilerArgumentsBuilder {
             return;
         }
 
-        Iterable<File> classpath = spec.getClasspath();
-        if (classpath != null && classpath.iterator().hasNext()) {
-            args.add("-classpath");
-            args.add(Joiner.on(File.pathSeparatorChar).join(classpath));
-        }
+        List<File> classpath = spec.getCompileClasspath();
+        args.add("-classpath");
+        args.add(classpath == null ? "" : Joiner.on(File.pathSeparatorChar).join(classpath));
     }
 
     private void addSourceFiles() {
