@@ -16,10 +16,14 @@
 
 package org.gradle.api.internal.tasks.compile.incremental.cache;
 
+import org.gradle.api.internal.tasks.compile.incremental.analyzer.ClassAnalysisCache;
 import org.gradle.api.internal.tasks.compile.incremental.deps.LocalClassSetAnalysisStore;
+import org.gradle.api.internal.tasks.compile.incremental.jar.JarSnapshotCache;
 import org.gradle.api.internal.tasks.compile.incremental.jar.LocalJarClasspathSnapshotStore;
 
-public interface CompileCaches extends GeneralCompileCaches {
+public interface CompileCaches {
+    ClassAnalysisCache getClassAnalysisCache();
+    JarSnapshotCache getJarSnapshotCache();
     LocalJarClasspathSnapshotStore getLocalJarClasspathSnapshotStore();
     LocalClassSetAnalysisStore getLocalClassSetAnalysisStore();
 }
