@@ -16,12 +16,15 @@
 
 package org.gradle.external.javadoc;
 
+import com.google.common.base.Objects;
+
+import java.io.Serializable;
 
 /**
  * This class is used to hold the information that can be provided to the javadoc executable via the -linkoffline
  * option.
  */
-public class JavadocOfflineLink {
+public class JavadocOfflineLink implements Serializable {
     private final String extDocUrl;
     private final String packagelistLoc;
 
@@ -38,6 +41,24 @@ public class JavadocOfflineLink {
         return packagelistLoc;
     }
 
+    @Override
+    public boolean equals(Object o) {
+        if (this == o) {
+            return true;
+        }
+        if (o == null || getClass() != o.getClass()) {
+            return false;
+        }
+        JavadocOfflineLink that = (JavadocOfflineLink) o;
+        return Objects.equal(extDocUrl, that.extDocUrl)
+            && Objects.equal(packagelistLoc, that.packagelistLoc);
+    }
+
+    @Override
+    public int hashCode() {
+        return Objects.hashCode(extDocUrl, packagelistLoc);
+    }
+
     public String toString() {
         return extDocUrl + "' '" + packagelistLoc;
     }
