@@ -18,25 +18,34 @@ package org.gradle.language.jvm.internal;
 
 import org.gradle.api.internal.component.ArtifactType;
 import org.gradle.api.internal.component.ComponentTypeRegistry;
+import org.gradle.api.internal.tasks.compile.daemon.InProcessCompilerDaemonFactory;
+import org.gradle.api.invocation.Gradle;
+import org.gradle.internal.classloader.ClassLoaderFactory;
 import org.gradle.internal.service.ServiceRegistration;
 import org.gradle.internal.service.scopes.PluginServiceRegistry;
 import org.gradle.jvm.JvmLibrary;
 import org.gradle.language.base.artifact.SourcesArtifact;
 
 public class JvmPluginServiceRegistry implements PluginServiceRegistry {
+    @Override
     public void registerGlobalServices(ServiceRegistration registration) {
     }
 
+    @Override
     public void registerBuildSessionServices(ServiceRegistration registration) {
     }
 
+    @Override
     public void registerBuildServices(ServiceRegistration registration) {
         registration.addProvider(new ComponentRegistrationAction());
     }
 
+    @Override
     public void registerGradleServices(ServiceRegistration registration) {
+        registration.addProvider(new GradleScopeJvmPluginServices());
     }
 
+    @Override
     public void registerProjectServices(ServiceRegistration registration) {
     }
 
@@ -51,4 +60,10 @@ public class JvmPluginServiceRegistry implements PluginServiceRegistry {
                 .registerArtifactType(SourcesArtifact.class, ArtifactType.SOURCES);
         }
     }
+
+    private static class GradleScopeJvmPluginServices {
+        InProcessCompilerDaemonFactory createInProcessCompilerDaemonFactory(ClassLoaderFactory classLoaderFactory, Gradle gradle) {
+            return new InProcessCompilerDaemonFactory(classLoaderFactory, gradle.getGradleUserHomeDir());
+        }
+    }
 }
