@@ -17,6 +17,7 @@ package org.gradle.language.nativeplatform.internal.incremental;
 
 import java.io.File;
 import java.util.List;
+import java.util.Set;
 
 public interface IncrementalCompilation {
     List<File> getRecompile();
@@ -24,4 +25,9 @@ public interface IncrementalCompilation {
     List<File> getRemoved();
 
     CompilationState getFinalState();
+
+    /**
+     * The set of all input locations that were discovered as part of resolving the dependencies for this compilation.
+     */
+    Set<File> getDiscoveredInputs();
 }
