@@ -16,12 +16,23 @@
 
 package org.gradle.launcher.daemon.client;
 
+import org.gradle.api.internal.DocumentationRegistry;
+import org.gradle.internal.jvm.inspection.JvmVersionDetector;
 import org.gradle.internal.service.ServiceRegistry;
+import org.gradle.launcher.daemon.bootstrap.DaemonGreeter;
 
 /**
  * Global services shared by all Gradle daemon clients in a given process.
  */
 public class DaemonClientGlobalServices {
+    JvmVersionValidator createJvmVersionValidator(JvmVersionDetector jvmVersionDetector) {
+        return new JvmVersionValidator(jvmVersionDetector);
+    }
+
+    DaemonGreeter createDaemonGreeter(DocumentationRegistry documentationRegistry) {
+        return new DaemonGreeter(documentationRegistry);
+    }
+
     DaemonClientFactory createClientFactory(ServiceRegistry sharedServices) {
         return new DaemonClientFactory(sharedServices);
     }
