@@ -16,20 +16,20 @@
 package org.gradle.launcher.daemon.server;
 
 import org.gradle.api.Action;
+import org.gradle.api.UncheckedIOException;
 import org.gradle.internal.concurrent.CompositeStoppable;
 import org.gradle.internal.concurrent.ExecutorFactory;
 import org.gradle.internal.id.UUIDGenerator;
 import org.gradle.internal.serialize.Serializers;
 import org.gradle.launcher.daemon.protocol.DaemonMessageSerializer;
 import org.gradle.launcher.daemon.protocol.Message;
-import org.gradle.messaging.remote.Address;
-import org.gradle.messaging.remote.ConnectionAcceptor;
-import org.gradle.messaging.remote.internal.ConnectCompletion;
-import org.gradle.messaging.remote.internal.IncomingConnector;
-import org.gradle.messaging.remote.internal.KryoBackedMessageSerializer;
-import org.gradle.messaging.remote.internal.MessageSerializer;
-import org.gradle.messaging.remote.internal.inet.InetAddressFactory;
-import org.gradle.messaging.remote.internal.inet.TcpIncomingConnector;
+import org.gradle.internal.remote.Address;
+import org.gradle.internal.remote.ConnectionAcceptor;
+import org.gradle.internal.remote.internal.ConnectCompletion;
+import org.gradle.internal.remote.internal.IncomingConnector;
+import org.gradle.internal.remote.internal.RemoteConnection;
+import org.gradle.internal.remote.internal.inet.InetAddressFactory;
+import org.gradle.internal.remote.internal.inet.TcpIncomingConnector;
 
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
@@ -53,7 +53,7 @@ public class DaemonTcpServerConnector implements DaemonServerConnector {
         );
     }
 
-    public Address start(final IncomingConnectionHandler handler) {
+    public Address start(final IncomingConnectionHandler handler, final Runnable connectionErrorHandler) {
         lifecycleLock.lock();
         try {
             if (stopped) {
@@ -68,8 +68,14 @@ public class DaemonTcpServerConnector implements DaemonServerConnector {
 
             Action<ConnectCompletion> connectEvent = new Action<ConnectCompletion>() {
                 public void execute(ConnectCompletion completion) {
-                    MessageSerializer<Message> serializer = new KryoBackedMessageSerializer<Message>(Serializers.stateful(DaemonMessageSerializer.create()));
-                    handler.handle(new SynchronizedDispatchConnection<Message>(completion.create(serializer)));
+                    RemoteConnection<Message> remoteConnection;
+                    try {
+                        remoteConnection = completion.create(Serializers.stateful(DaemonMessageSerializer.create()));
+                    } catch (UncheckedIOException e) {
+                        connectionErrorHandler.run();
+                        throw e;
+                    }
+                    handler.handle(new SynchronizedDispatchConnection<Message>(remoteConnection));
                 }
             };
 
@@ -92,4 +98,4 @@ public class DaemonTcpServerConnector implements DaemonServerConnector {
         CompositeStoppable.stoppable(acceptor, incomingConnector).stop();
     }
 
-}
\ No newline at end of file
+}
