@@ -17,7 +17,6 @@
 package org.gradle.model.internal.core;
 
 import org.gradle.api.Nullable;
-import org.gradle.model.internal.type.ModelType;
 
 /**
  * A predicate that selects model nodes.
@@ -46,27 +45,12 @@ public abstract class ModelPredicate {
     }
 
     /**
-     * Return the path of the scope of the nodes to select, or null if scope is not relevant.
+     * Return the path of the scope of the nodes to select, or null if ancestor is not relevant.
      *
-     * <p>A node will be selected if its path or its parent's path equals the specified path.</p>
+     * <p>A node will be selected if its path or one of its ancestor's path equals the specified path.</p>
      */
     @Nullable
     public ModelPath getAncestor() {
         return null;
     }
-
-    /**
-     * Returns the type of node to select, or null if type is not relevant.
-     */
-    @Nullable
-    public ModelType<?> getType() {
-        return null;
-    }
-
-    /**
-     * Returns whether the node to select must satisfy a type. Returns {code true} if the type is not relevant.
-     */
-    public boolean isUntyped() {
-        return true;
-    }
 }
