@@ -21,7 +21,6 @@ import net.jcip.annotations.ThreadSafe;
 import org.gradle.api.Nullable;
 import org.gradle.api.specs.Spec;
 import org.gradle.internal.Cast;
-import org.gradle.model.InvalidModelRuleDeclarationException;
 import org.gradle.model.Path;
 import org.gradle.model.internal.core.ModelPath;
 import org.gradle.model.internal.core.ModelReference;
@@ -32,6 +31,7 @@ import org.gradle.model.internal.type.ModelType;
 
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Method;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 
@@ -39,19 +39,31 @@ import static org.gradle.util.CollectionUtils.findFirst;
 
 @ThreadSafe
 public class DefaultMethodRuleDefinition<T, R, S> implements MethodRuleDefinition<R, S> {
-    private ImmutableList<ModelReference<?>> references;
+    private static final String[] PARAMETER_DESC;
 
+    static {
+        PARAMETER_DESC = new String[255];
+        for (int i = 0; i < PARAMETER_DESC.length; i++) {
+            PARAMETER_DESC[i] = "parameter " + (i+1);
+        }
+    }
+
+    private List<ModelReference<?>> references;
+    private List<List<Annotation>> parameterAnnotations;
     private final WeaklyTypeReferencingMethod<T, R> method;
 
     private DefaultMethodRuleDefinition(Method method, ModelType<T> instanceType, ModelType<R> returnType) {
         this.method = WeaklyTypeReferencingMethod.of(instanceType, returnType, method);
 
         ImmutableList.Builder<ModelReference<?>> referencesBuilder = ImmutableList.builder();
+        ImmutableList.Builder<List<Annotation>> parameterAnnotationsBuilder = ImmutableList.builder();
         for (int i = 0; i < method.getGenericParameterTypes().length; i++) {
-            Annotation[] paramAnnotations = method.getParameterAnnotations()[i];
+            List<Annotation> paramAnnotations = Arrays.asList(method.getParameterAnnotations()[i]);
+            parameterAnnotationsBuilder.add(paramAnnotations);
             referencesBuilder.add(reference(paramAnnotations, i));
         }
         this.references = referencesBuilder.build();
+        this.parameterAnnotations = parameterAnnotationsBuilder.build();
     }
 
     public static <T> MethodRuleDefinition<?, ?> create(Class<T> source, Method method) {
@@ -63,10 +75,17 @@ public class DefaultMethodRuleDefinition<T, R, S> implements MethodRuleDefinitio
         return new DefaultMethodRuleDefinition<T, R, S>(method, ModelType.of(source), returnType);
     }
 
+    @Override
+    public WeaklyTypeReferencingMethod<?, R> getMethod() {
+        return method;
+    }
+
+    @Override
     public String getMethodName() {
         return method.getName();
     }
 
+    @Override
     public ModelType<R> getReturnType() {
         return method.getReturnType();
     }
@@ -89,45 +108,32 @@ public class DefaultMethodRuleDefinition<T, R, S> implements MethodRuleDefinitio
 
     @Override
     public <A extends Annotation> A getAnnotation(Class<A> annotationType) {
-        for (Annotation annotation : method.getAnnotations()) {
-            if (annotationType.isAssignableFrom(annotation.getClass())) {
-                return Cast.uncheckedCast(annotation);
-            }
-        }
-        return null;
+        return method.getMethod().getAnnotation(annotationType);
     }
 
+    @Override
     public ModelRuleDescriptor getDescriptor() {
-        return new MethodModelRuleDescriptor(method);
-    }
-
-    public ModelRuleInvoker<R> getRuleInvoker() {
-        return new DefaultModelRuleInvoker<T, R>(method);
+        return MethodModelRuleDescriptor.of(method);
     }
 
+    @Override
     public List<ModelReference<?>> getReferences() {
         return references;
     }
 
-    private ModelReference<?> reference(Annotation[] annotations, int i) {
+    @Override
+    public List<List<Annotation>> getParameterAnnotations() {
+        return parameterAnnotations;
+    }
+
+    private ModelReference<?> reference(List<Annotation> annotations, int i) {
         Path pathAnnotation = (Path) findFirst(annotations, new Spec<Annotation>() {
             public boolean isSatisfiedBy(Annotation element) {
                 return element.annotationType().equals(Path.class);
             }
         });
-        String path = pathAnnotation == null ? null : pathAnnotation.value();
-        ModelType<?> cast = ModelType.of(method.getGenericParameterTypes()[i]);
-        return ModelReference.of(path == null ? null : validPath(path), cast, String.format("parameter %s", i + 1));
+        ModelPath path = pathAnnotation == null ? null : ModelPath.path(pathAnnotation.value());
+        ModelType<?> cast = method.getGenericParameterTypes().get(i);
+        return ModelReference.of(path, cast, PARAMETER_DESC[i]);
     }
-
-    private ModelPath validPath(String path) {
-        try {
-            return ModelPath.validatedPath(path);
-        } catch (ModelPath.InvalidPathException e) {
-            throw new InvalidModelRuleDeclarationException(getDescriptor(), e);
-        } catch (ModelPath.InvalidNameException e) {
-            throw new InvalidModelRuleDeclarationException(getDescriptor(), e);
-        }
-    }
-
 }
