@@ -16,9 +16,12 @@
 
 package org.gradle.model.internal.manage.schema;
 
+import org.gradle.api.Nullable;
 import org.gradle.model.internal.manage.schema.extract.ModelSchemaAspect;
+import org.gradle.model.internal.method.WeaklyTypeReferencingMethod;
 
 import java.util.Collection;
+import java.util.Set;
 import java.util.SortedSet;
 
 /**
@@ -29,10 +32,15 @@ public interface StructSchema<T> extends ModelSchema<T> {
 
     SortedSet<String> getPropertyNames();
 
+    @Nullable
     ModelProperty<?> getProperty(String name);
 
     Collection<ModelProperty<?>> getProperties();
 
+    Set<WeaklyTypeReferencingMethod<?, ?>> getNonPropertyMethods();
+
+    Set<WeaklyTypeReferencingMethod<?, ?>> getAllMethods();
+
     boolean hasAspect(Class<? extends ModelSchemaAspect> aspectType);
 
     <A extends ModelSchemaAspect> A getAspect(Class<A> aspectType);
