@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 the original author or authors.
+ * Copyright 2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,13 +16,6 @@
 
 package org.gradle.platform.base.internal;
 
-import org.gradle.platform.base.ComponentSpec;
-import org.gradle.platform.base.TransformationFileType;
-
-import java.util.Set;
-
-public interface ComponentSpecInternal extends ComponentSpec {
-
-    Set<? extends Class<? extends TransformationFileType>> getInputTypes();
-
+public interface ComponentSpecInternal {
+    ComponentSpecIdentifier getIdentifier();
 }
