@@ -22,7 +22,8 @@ import org.gradle.api.tasks.Input;
 import org.gradle.api.tasks.OutputFile;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.internal.ErroringAction;
-import org.gradle.jvm.tasks.api.internal.ApiClassExtractor;
+import org.gradle.api.internal.tasks.compile.ApiClassExtractor;
+import org.gradle.util.internal.Java9ClassReader;
 import org.objectweb.asm.ClassReader;
 
 import java.io.BufferedOutputStream;
@@ -63,9 +64,8 @@ import static org.gradle.internal.IoActions.withResource;
  * {@link UnsupportedOperationException} in the unlikely event that they are present on
  * the classpath and invoked at runtime.</p>
  *
- * <p>The inputs to this task are Java class files which must be provided via one of the
- * many {@link org.gradle.api.tasks.TaskInputs#sourceDir(Object)} and
- * {@link org.gradle.api.tasks.TaskInputs#source(Object)} overloads.</p>
+ * <p>The inputs to this task are Java class files which must be provided via
+ * {@link org.gradle.api.tasks.TaskInputs}.</p>
  *
  * @since 2.10
  * @see org.gradle.jvm.plugins.JvmComponentPlugin
@@ -114,19 +114,22 @@ public class ApiJar extends DefaultTask {
 
                 private void writeClasses(JarOutputStream jos) throws Exception {
                     for (File sourceFile : sourceFiles) {
-                        // TODO:RBO consider filtering the sources FileCollection directly
                         if (!isClassFile(sourceFile)) {
                             continue;
                         }
-                        ClassReader classReader = new ClassReader(readFileToByteArray(sourceFile));
+                        ClassReader classReader = new Java9ClassReader(readFileToByteArray(sourceFile));
                         if (!apiClassExtractor.shouldExtractApiClassFrom(classReader)) {
                             continue;
                         }
 
                         byte[] apiClassBytes = apiClassExtractor.extractApiClassFrom(classReader);
+                        if (apiClassBytes == null) {
+                            // Should be excluded
+                            continue;
+                        }
+
                         String internalClassName = classReader.getClassName();
                         String entryPath = internalClassName + ".class";
-                        // TODO:RBO consider what to do about duplicate class names
                         writeEntry(jos, entryPath, apiClassBytes);
                     }
                 }
@@ -150,7 +153,6 @@ public class ApiJar extends DefaultTask {
     }
 
     private File[] sortedSourceFiles() {
-        // TODO:RBO investigate the possibility and performance implications of getting a sorted file list directly from FileCollection
         final File[] sourceFiles = (File[]) getInputs().getSourceFiles().asType(File[].class);
         Arrays.sort(sourceFiles);
         return sourceFiles;
