@@ -16,7 +16,7 @@
 
 package org.gradle.play;
 
-import org.gradle.api.BuildableModelElement;
+import org.gradle.api.BuildableComponentSpec;
 import org.gradle.api.Incubating;
 
 import java.io.File;
@@ -26,7 +26,7 @@ import java.util.Set;
  * A set of public assets added to a binary.
  */
 @Incubating
-public interface PublicAssets extends BuildableModelElement {
+public interface PublicAssets extends BuildableComponentSpec {
     /**
      * A set of asset directories for this binary.
      */
