@@ -40,6 +40,7 @@ public class TwirlCompiler implements Compiler<TwirlCompileSpec>, Serializable {
         this.adapter = adapter;
     }
 
+    @Override
     public WorkResult execute(TwirlCompileSpec spec) {
         ArrayList<File> outputFiles = Lists.newArrayList();
         try {
@@ -47,7 +48,7 @@ public class TwirlCompiler implements Compiler<TwirlCompileSpec>, Serializable {
             ScalaMethod compile = adapter.getCompileMethod(cl);
             Iterable<RelativeFile> sources = spec.getSources();
             for (RelativeFile sourceFile : sources) {
-                Object result = compile.invoke(adapter.createCompileParameters(cl, sourceFile.getFile(), sourceFile.getBaseDir(), spec.getDestinationDir(), spec.isJavaProject()));
+                Object result = compile.invoke(adapter.createCompileParameters(cl, sourceFile.getFile(), sourceFile.getBaseDir(), spec.getDestinationDir(), spec.getDefaultImports()));
                 ScalaOptionInvocationWrapper<File> maybeFile = new ScalaOptionInvocationWrapper<File>(result);
                 if (maybeFile.isDefined()) {
                     outputFiles.add(maybeFile.get());
