@@ -17,7 +17,7 @@ package controllers.jva;
 
 import play.*;
 import play.mvc.*;
-import views.html.*;
+import jva.html.*;
 
 public class PureJava extends Controller {
 
@@ -25,4 +25,4 @@ public class PureJava extends Controller {
         return ok(index.render("Your new application is ready."));
     }
 
-}
\ No newline at end of file
+}
