@@ -24,6 +24,7 @@ import org.gradle.api.Project;
 import org.gradle.api.Task;
 import org.gradle.api.artifacts.Configuration;
 import org.gradle.api.artifacts.ConfigurationContainer;
+import org.gradle.api.attributes.Usage;
 import org.gradle.api.file.SourceDirectorySet;
 import org.gradle.api.internal.ConventionMapping;
 import org.gradle.api.internal.IConventionAware;
@@ -38,11 +39,13 @@ import org.gradle.api.internal.tasks.SourceSetCompileClasspath;
 import org.gradle.api.internal.tasks.testing.NoMatchingTestsReporter;
 import org.gradle.api.reporting.ReportingExtension;
 import org.gradle.api.tasks.Copy;
+import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.SourceSet;
 import org.gradle.api.tasks.compile.AbstractCompile;
 import org.gradle.api.tasks.compile.JavaCompile;
 import org.gradle.api.tasks.javadoc.Javadoc;
 import org.gradle.api.tasks.testing.Test;
+import org.gradle.internal.Factory;
 import org.gradle.internal.reflect.Instantiator;
 import org.gradle.jvm.Classpath;
 import org.gradle.jvm.platform.internal.DefaultJavaPlatform;
@@ -61,6 +64,7 @@ import org.gradle.platform.base.BinaryContainer;
 import org.gradle.platform.base.internal.BinarySpecInternal;
 import org.gradle.platform.base.internal.DefaultComponentSpecIdentifier;
 import org.gradle.platform.base.plugins.BinaryBasePlugin;
+import org.gradle.util.DeprecationLogger;
 import org.gradle.util.WrapUtil;
 
 import javax.inject.Inject;
@@ -68,6 +72,8 @@ import java.io.File;
 import java.util.List;
 import java.util.concurrent.Callable;
 
+import static org.gradle.api.attributes.Usage.*;
+
 /**
  * <p>A {@link org.gradle.api.Plugin} which compiles and tests Java source, and assembles it into a JAR file.</p>
  */
@@ -114,6 +120,11 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
         configureTest(project, javaConvention);
         configureBuildNeeded(project);
         configureBuildDependents(project);
+        configureSchema(project);
+    }
+
+    private void configureSchema(ProjectInternal project) {
+        project.getDependencies().getAttributesSchema().attribute(Usage.USAGE_ATTRIBUTE);
     }
 
     private BridgedBinaries configureSourceSetDefaults(final JavaPluginConvention pluginConvention) {
@@ -201,7 +212,7 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
     private void definePathsForSourceSet(final SourceSet sourceSet, ConventionMapping outputConventionMapping, final Project project) {
         outputConventionMapping.map("classesDir", new Callable<Object>() {
             public Object call() throws Exception {
-                String classesDirName = "classes/" +   sourceSet.getName();
+                String classesDirName = "classes/" + sourceSet.getName();
                 return new File(project.getBuildDir(), classesDirName);
             }
         });
@@ -217,27 +228,59 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
     }
 
     private void defineConfigurationsForSourceSet(SourceSet sourceSet, ConfigurationContainer configurations) {
-        Configuration compileConfiguration = configurations.maybeCreate(sourceSet.getCompileConfigurationName());
-        compileConfiguration.setVisible(false);
-        compileConfiguration.setDescription("Dependencies for " + sourceSet + ".");
+        String compileConfigurationName = sourceSet.getCompileConfigurationName();
+        String implementationConfigurationName = sourceSet.getImplementationConfigurationName();
+        String runtimeConfigurationName = sourceSet.getRuntimeConfigurationName();
+        String runtimeOnlyConfigurationName = sourceSet.getRuntimeOnlyConfigurationName();
+        String compileOnlyConfigurationName = sourceSet.getCompileOnlyConfigurationName();
+        String compileClasspathConfigurationName = sourceSet.getCompileClasspathConfigurationName();
+        String runtimeClasspathConfigurationName = sourceSet.getRuntimeClasspathConfigurationName();
+        String sourceSetName = sourceSet.toString();
 
-        Configuration runtimeConfiguration = configurations.maybeCreate(sourceSet.getRuntimeConfigurationName());
+        Configuration compileConfiguration = configurations.maybeCreate(compileConfigurationName);
+        compileConfiguration.setVisible(false);
+        compileConfiguration.setDescription("Dependencies for " + sourceSetName + " (deprecated, use '" + implementationConfigurationName + " ' instead).");
+
+        Configuration implementationConfiguration = configurations.maybeCreate(implementationConfigurationName);
+        implementationConfiguration.setVisible(false);
+        implementationConfiguration.setDescription("Implementation only dependencies for " + sourceSetName + ".");
+        implementationConfiguration.setCanBeConsumed(false);
+        implementationConfiguration.setCanBeResolved(false);
+        implementationConfiguration.extendsFrom(compileConfiguration);
+
+        Configuration runtimeConfiguration = configurations.maybeCreate(runtimeConfigurationName);
         runtimeConfiguration.setVisible(false);
         runtimeConfiguration.extendsFrom(compileConfiguration);
-        runtimeConfiguration.setDescription("Runtime dependencies for " + sourceSet + ".");
+        runtimeConfiguration.setDescription("Runtime dependencies for " + sourceSetName + " (deprecated, use '" + runtimeOnlyConfigurationName + " ' instead).");
 
-        Configuration compileOnlyConfiguration = configurations.maybeCreate(sourceSet.getCompileOnlyConfigurationName());
+        Configuration compileOnlyConfiguration = configurations.maybeCreate(compileOnlyConfigurationName);
         compileOnlyConfiguration.setVisible(false);
-        compileOnlyConfiguration.extendsFrom(compileConfiguration);
-        compileOnlyConfiguration.setDescription("Compile dependencies for " + sourceSet + ".");
+        compileOnlyConfiguration.setDescription("Compile only dependencies for " + sourceSetName + ".");
 
-        Configuration compileClasspathConfiguration = configurations.maybeCreate(sourceSet.getCompileClasspathConfigurationName());
+        Configuration compileClasspathConfiguration = configurations.maybeCreate(compileClasspathConfigurationName);
         compileClasspathConfiguration.setVisible(false);
-        compileClasspathConfiguration.extendsFrom(compileOnlyConfiguration);
-        compileClasspathConfiguration.setDescription("Compile classpath for " + sourceSet + ".");
+        compileClasspathConfiguration.extendsFrom(compileOnlyConfiguration, implementationConfiguration);
+        compileClasspathConfiguration.setDescription("Compile classpath for " + sourceSetName + ".");
+        compileClasspathConfiguration.setCanBeConsumed(false);
+        compileClasspathConfiguration.getAttributes().attribute(USAGE_ATTRIBUTE, FOR_COMPILE);
+
+        Configuration runtimeOnlyConfiguration = configurations.maybeCreate(runtimeOnlyConfigurationName);
+        runtimeOnlyConfiguration.setVisible(false);
+        runtimeOnlyConfiguration.setCanBeConsumed(false);
+        runtimeOnlyConfiguration.setCanBeResolved(false);
+        runtimeOnlyConfiguration.setDescription("Runtime only dependencies for " + sourceSetName + ".");
+
+        Configuration runtimeClasspathConfiguration = configurations.maybeCreate(runtimeClasspathConfigurationName);
+        runtimeClasspathConfiguration.setVisible(false);
+        runtimeClasspathConfiguration.setCanBeConsumed(false);
+        runtimeClasspathConfiguration.setCanBeResolved(true);
+        runtimeClasspathConfiguration.setDescription("Runtime classpath of " + sourceSetName + ".");
+        runtimeClasspathConfiguration.extendsFrom(runtimeOnlyConfiguration, runtimeConfiguration, implementationConfiguration);
+        runtimeClasspathConfiguration.getAttributes().attribute(USAGE_ATTRIBUTE, FOR_RUNTIME);
 
         sourceSet.setCompileClasspath(compileClasspathConfiguration);
-        sourceSet.setRuntimeClasspath(sourceSet.getOutput().plus(runtimeConfiguration));
+        sourceSet.setRuntimeClasspath(sourceSet.getOutput().plus(runtimeClasspathConfiguration));
+
     }
 
     public void configureForSourceSet(final SourceSet sourceSet, AbstractCompile compile) {
@@ -274,11 +317,18 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
             }
         });
         project.getTasks().withType(JavaCompile.class, new Action<JavaCompile>() {
+            @Override
             public void execute(final JavaCompile compile) {
                 ConventionMapping conventionMapping = compile.getConventionMapping();
                 conventionMapping.map("dependencyCacheDir", new Callable<Object>() {
+                    @Override
                     public Object call() throws Exception {
-                        return javaConvention.getDependencyCacheDir();
+                        return DeprecationLogger.whileDisabled(new Factory<Object>() {
+                            @Override
+                            public Object create() {
+                                return javaConvention.getDependencyCacheDir();
+                            }
+                        });
                     }
                 });
             }
@@ -314,6 +364,14 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
         buildTask.setDescription("Assembles and tests this project and all projects that depend on it.");
         buildTask.setGroup(BasePlugin.BUILD_GROUP);
         buildTask.dependsOn(BUILD_TASK_NAME);
+        buildTask.doFirst(new Action<Task>() {
+            @Override
+            public void execute(Task task) {
+                if (!task.getProject().getGradle().getIncludedBuilds().isEmpty()) {
+                    task.getProject().getLogger().warn("[composite-build] Warning: `" + task.getPath() + "` task does not build included builds.");
+                }
+            }
+        });
     }
 
     private void configureTest(final Project project, final JavaPluginConvention convention) {
@@ -352,7 +410,10 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
             //configure inputs so that the test task is skipped when there are no source files.
             //unfortunately, this only applies when 'test.single' is *not* applied
             //We should fix this distinction, the behavior with 'test.single' or without it should be the same
-            test.getInputs().files(test.getCandidateClassFiles()).withPropertyName("test.candidateClassFiles").skipWhenEmpty();
+            test.getInputs().files(test.getCandidateClassFiles())
+                .withPropertyName("nonEmptyCandidateClassFiles")
+                .withPathSensitivity(PathSensitivity.RELATIVE)
+                .skipWhenEmpty();
             return;
         }
         test.prependParallelSafeAction(new Action<Task>() {
@@ -418,4 +479,5 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
             }
         }
     }
+
 }
