@@ -18,7 +18,7 @@ package org.gradle.internal.resource.transport.sftp;
 
 import com.jcraft.jsch.ChannelSftp;
 import org.gradle.api.artifacts.repositories.PasswordCredentials;
-import org.gradle.internal.resource.ResourceException;
+import org.gradle.api.resources.ResourceException;
 import org.gradle.internal.resource.transfer.ExternalResourceLister;
 
 import java.net.URI;
