@@ -18,9 +18,7 @@ package org.gradle.api.internal.tasks.testing;
 
 import org.gradle.api.Nullable;
 
-import java.io.Serializable;
-
-public class TestStartEvent implements Serializable {
+public class TestStartEvent {
     private final long startTime;
     private final Object parentId;
 
