@@ -16,12 +16,12 @@
 
 package org.gradle.tooling.internal.consumer;
 
-import org.gradle.internal.TrueTimeProvider;
+import org.gradle.internal.time.TrueTimeProvider;
 import org.gradle.internal.event.DefaultListenerManager;
 import org.gradle.internal.event.ListenerManager;
-import org.gradle.logging.ProgressLoggerFactory;
-import org.gradle.logging.internal.DefaultProgressLoggerFactory;
-import org.gradle.logging.internal.ProgressListener;
+import org.gradle.internal.logging.progress.ProgressLoggerFactory;
+import org.gradle.internal.logging.progress.DefaultProgressLoggerFactory;
+import org.gradle.internal.logging.progress.ProgressListener;
 
 /**
  * Provides logging services per thread.
@@ -57,4 +57,4 @@ public class SynchronizedLogging implements LoggingProvider {
             this.progressLoggerFactory = progressLoggerFactory;
         }
     }
-}
\ No newline at end of file
+}
